# openapi_client

FireflyIIIClient - the Ruby gem for the Firefly III API

This is the official documentation of the Firefly III API. You can find accompanying documentation on the website of Firefly III itself (see below). Please report any bugs or issues. This version of the API is live from version v4.7.9 and onwards. You may use the \"Authorize\" button to try the API below.


This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.10.4-modified
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://firefly-iii.org](https://firefly-iii.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build firefly-iii-client.gemspec
```

Then either install the gem locally:

```shell
gem install ./firefly_iii_client-1.0.0.gem
```

(for development, run `gem install --dev ./openapi_client-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'openapi_client', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'openapi_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'firefly_iii_client'

# Setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AboutApi.new

begin
  #System information end point.
  result = api_instance.get_about
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Exception when calling AboutApi->get_about: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://demo.firefly-iii.org*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*FireflyIIIClient::AboutApi* | [**get_about**](docs/AboutApi.md#get_about) | **GET** /api/v1/about | System information end point.
*FireflyIIIClient::AboutApi* | [**get_current_user**](docs/AboutApi.md#get_current_user) | **GET** /api/v1/about/user | Currently authenticated user endpoint.
*FireflyIIIClient::AccountsApi* | [**delete_account**](docs/AccountsApi.md#delete_account) | **DELETE** /api/v1/accounts/{id} | Permanently delete account.
*FireflyIIIClient::AccountsApi* | [**get_account**](docs/AccountsApi.md#get_account) | **GET** /api/v1/accounts/{id} | Get single account.
*FireflyIIIClient::AccountsApi* | [**list_account**](docs/AccountsApi.md#list_account) | **GET** /api/v1/accounts | List all accounts.
*FireflyIIIClient::AccountsApi* | [**list_piggy_bank_by_account**](docs/AccountsApi.md#list_piggy_bank_by_account) | **GET** /api/v1/accounts/{id}/piggy_banks | List all piggy banks related to the account.
*FireflyIIIClient::AccountsApi* | [**list_transaction_by_account**](docs/AccountsApi.md#list_transaction_by_account) | **GET** /api/v1/accounts/{id}/transactions | List all transactions related to the account.
*FireflyIIIClient::AccountsApi* | [**store_account**](docs/AccountsApi.md#store_account) | **POST** /api/v1/accounts | Create new account.
*FireflyIIIClient::AccountsApi* | [**update_account**](docs/AccountsApi.md#update_account) | **PUT** /api/v1/accounts/{id} | Update existing account.
*FireflyIIIClient::AttachmentsApi* | [**delete_attachment**](docs/AttachmentsApi.md#delete_attachment) | **DELETE** /api/v1/attachments/{id} | Delete an attachment.
*FireflyIIIClient::AttachmentsApi* | [**download_attachment**](docs/AttachmentsApi.md#download_attachment) | **GET** /api/v1/attachments/{id}/download | Download a single attachment.
*FireflyIIIClient::AttachmentsApi* | [**get_attachment**](docs/AttachmentsApi.md#get_attachment) | **GET** /api/v1/attachments/{id} | Get a single attachment.
*FireflyIIIClient::AttachmentsApi* | [**list_attachment**](docs/AttachmentsApi.md#list_attachment) | **GET** /api/v1/attachments | List all attachments.
*FireflyIIIClient::AttachmentsApi* | [**store_attachment**](docs/AttachmentsApi.md#store_attachment) | **POST** /api/v1/attachments | Store a new attachment.
*FireflyIIIClient::AttachmentsApi* | [**update_attachment**](docs/AttachmentsApi.md#update_attachment) | **PUT** /api/v1/attachments/{id} | Update existing attachment.
*FireflyIIIClient::AttachmentsApi* | [**upload_attachment**](docs/AttachmentsApi.md#upload_attachment) | **POST** /api/v1/attachments/{id}/upload | Upload an attachment.
*FireflyIIIClient::AvailableBudgetsApi* | [**delete_available_budget**](docs/AvailableBudgetsApi.md#delete_available_budget) | **DELETE** /api/v1/available_budgets/{id} | Delete an available budget.
*FireflyIIIClient::AvailableBudgetsApi* | [**get_available_budget**](docs/AvailableBudgetsApi.md#get_available_budget) | **GET** /api/v1/available_budgets/{id} | Get a single available budget.
*FireflyIIIClient::AvailableBudgetsApi* | [**list_available_budget**](docs/AvailableBudgetsApi.md#list_available_budget) | **GET** /api/v1/available_budgets | List all available budget amounts.
*FireflyIIIClient::AvailableBudgetsApi* | [**store_available_budget**](docs/AvailableBudgetsApi.md#store_available_budget) | **POST** /api/v1/available_budgets | Store a new available budget
*FireflyIIIClient::AvailableBudgetsApi* | [**update_available_budget**](docs/AvailableBudgetsApi.md#update_available_budget) | **PUT** /api/v1/available_budgets/{id} | Update existing available budget, to change for example the date range of the amount or the amount itself.
*FireflyIIIClient::BillsApi* | [**delete_bill**](docs/BillsApi.md#delete_bill) | **DELETE** /api/v1/bills/{id} | Delete a bill.
*FireflyIIIClient::BillsApi* | [**get_bill**](docs/BillsApi.md#get_bill) | **GET** /api/v1/bills/{id} | Get a single bill.
*FireflyIIIClient::BillsApi* | [**list_attachment_by_bill**](docs/BillsApi.md#list_attachment_by_bill) | **GET** /api/v1/bills/{id}/attachments | List all attachments uploaded to the bill.
*FireflyIIIClient::BillsApi* | [**list_bill**](docs/BillsApi.md#list_bill) | **GET** /api/v1/bills | List all bills.
*FireflyIIIClient::BillsApi* | [**list_rule_by_bill**](docs/BillsApi.md#list_rule_by_bill) | **GET** /api/v1/bills/{id}/rules | List all rules associated with the bill.
*FireflyIIIClient::BillsApi* | [**list_transaction_by_bill**](docs/BillsApi.md#list_transaction_by_bill) | **GET** /api/v1/bills/{id}/transactions | List all transactions associated with the  bill.
*FireflyIIIClient::BillsApi* | [**store_bill**](docs/BillsApi.md#store_bill) | **POST** /api/v1/bills | Store a new bill
*FireflyIIIClient::BillsApi* | [**update_bill**](docs/BillsApi.md#update_bill) | **PUT** /api/v1/bills/{id} | Update existing bill.
*FireflyIIIClient::BudgetsApi* | [**delete_budget**](docs/BudgetsApi.md#delete_budget) | **DELETE** /api/v1/budgets/{id} | Delete a budget.
*FireflyIIIClient::BudgetsApi* | [**delete_budget_limit**](docs/BudgetsApi.md#delete_budget_limit) | **DELETE** /api/v1/budgets/limits/{id} | Delete a budget limit.
*FireflyIIIClient::BudgetsApi* | [**get_budget**](docs/BudgetsApi.md#get_budget) | **GET** /api/v1/budgets/{id} | Get a single budget.
*FireflyIIIClient::BudgetsApi* | [**get_budget_limit**](docs/BudgetsApi.md#get_budget_limit) | **GET** /api/v1/budgets/limits/{id} | Get single budget limit.
*FireflyIIIClient::BudgetsApi* | [**list_budget**](docs/BudgetsApi.md#list_budget) | **GET** /api/v1/budgets | List all budgets.
*FireflyIIIClient::BudgetsApi* | [**list_budget_limit_by_budget**](docs/BudgetsApi.md#list_budget_limit_by_budget) | **GET** /api/v1/budgets/{id}/limits | Get all limits
*FireflyIIIClient::BudgetsApi* | [**list_transaction_by_budget**](docs/BudgetsApi.md#list_transaction_by_budget) | **GET** /api/v1/budgets/{id}/transactions | All transactions to a budget.
*FireflyIIIClient::BudgetsApi* | [**list_transaction_by_budget_limit**](docs/BudgetsApi.md#list_transaction_by_budget_limit) | **GET** /api/v1/budgets/limits/{id}/transactions | List all transactions by a budget limit ID.
*FireflyIIIClient::BudgetsApi* | [**store_budget**](docs/BudgetsApi.md#store_budget) | **POST** /api/v1/budgets | Store a new budget
*FireflyIIIClient::BudgetsApi* | [**store_budget_limit**](docs/BudgetsApi.md#store_budget_limit) | **POST** /api/v1/budgets/{id}/limits | Store new budget limit.
*FireflyIIIClient::BudgetsApi* | [**update_budget**](docs/BudgetsApi.md#update_budget) | **PUT** /api/v1/budgets/{id} | Update existing budget.
*FireflyIIIClient::BudgetsApi* | [**update_budget_limit**](docs/BudgetsApi.md#update_budget_limit) | **PUT** /api/v1/budgets/limits/{id} | Update existing budget limit.
*FireflyIIIClient::CategoriesApi* | [**delete_category**](docs/CategoriesApi.md#delete_category) | **DELETE** /api/v1/categories/{id} | Delete a category.
*FireflyIIIClient::CategoriesApi* | [**get_category**](docs/CategoriesApi.md#get_category) | **GET** /api/v1/categories/{id} | Get a single category.
*FireflyIIIClient::CategoriesApi* | [**list_category**](docs/CategoriesApi.md#list_category) | **GET** /api/v1/categories | List all categories.
*FireflyIIIClient::CategoriesApi* | [**list_transaction_by_category**](docs/CategoriesApi.md#list_transaction_by_category) | **GET** /api/v1/categories/{id}/transactions | List all transactions in a category.
*FireflyIIIClient::CategoriesApi* | [**store_category**](docs/CategoriesApi.md#store_category) | **POST** /api/v1/categories | Store a new category
*FireflyIIIClient::CategoriesApi* | [**update_category**](docs/CategoriesApi.md#update_category) | **PUT** /api/v1/categories/{id} | Update existing category.
*FireflyIIIClient::ChartsApi* | [**get_chart_ab_overview**](docs/ChartsApi.md#get_chart_ab_overview) | **GET** /api/v1/chart/ab/overview/{id} | Dashboard chart with an overview of the available budget.
*FireflyIIIClient::ChartsApi* | [**get_chart_account_expense**](docs/ChartsApi.md#get_chart_account_expense) | **GET** /api/v1/chart/account/expense | Dashboard chart with expense account balance information.
*FireflyIIIClient::ChartsApi* | [**get_chart_account_overview**](docs/ChartsApi.md#get_chart_account_overview) | **GET** /api/v1/chart/account/overview | Dashboard chart with asset account balance information.
*FireflyIIIClient::ChartsApi* | [**get_chart_account_revenue**](docs/ChartsApi.md#get_chart_account_revenue) | **GET** /api/v1/chart/account/revenue | Dashboard chart with revenue account balance information.
*FireflyIIIClient::ChartsApi* | [**get_chart_category_overview**](docs/ChartsApi.md#get_chart_category_overview) | **GET** /api/v1/chart/category/overview | Dashboard chart with an overview of the users categories.
*FireflyIIIClient::ConfigurationApi* | [**get_configuration**](docs/ConfigurationApi.md#get_configuration) | **GET** /api/v1/configuration | Get Firefly III system configuration.
*FireflyIIIClient::ConfigurationApi* | [**set_configuration**](docs/ConfigurationApi.md#set_configuration) | **POST** /api/v1/configuration/{name} | Update configuration
*FireflyIIIClient::CurrenciesApi* | [**default_currency**](docs/CurrenciesApi.md#default_currency) | **POST** /api/v1/currencies/{code}/default | Make currency default currency.
*FireflyIIIClient::CurrenciesApi* | [**delete_currency**](docs/CurrenciesApi.md#delete_currency) | **DELETE** /api/v1/currencies/{code} | Delete a currency.
*FireflyIIIClient::CurrenciesApi* | [**disable_currency**](docs/CurrenciesApi.md#disable_currency) | **POST** /api/v1/currencies/{code}/disable | Disable a currency.
*FireflyIIIClient::CurrenciesApi* | [**enable_currency**](docs/CurrenciesApi.md#enable_currency) | **POST** /api/v1/currencies/{code}/enable | Enable a single currency.
*FireflyIIIClient::CurrenciesApi* | [**get_currency**](docs/CurrenciesApi.md#get_currency) | **GET** /api/v1/currencies/{code} | Get a single currency.
*FireflyIIIClient::CurrenciesApi* | [**list_account_by_currency**](docs/CurrenciesApi.md#list_account_by_currency) | **GET** /api/v1/currencies/{code}/accounts | List all accounts with this currency.
*FireflyIIIClient::CurrenciesApi* | [**list_available_budget_by_currency**](docs/CurrenciesApi.md#list_available_budget_by_currency) | **GET** /api/v1/currencies/{code}/available_budgets | List all available budgets with this currency.
*FireflyIIIClient::CurrenciesApi* | [**list_bill_by_currency**](docs/CurrenciesApi.md#list_bill_by_currency) | **GET** /api/v1/currencies/{code}/bills | List all bills with this currency.
*FireflyIIIClient::CurrenciesApi* | [**list_budget_limit_by_currency**](docs/CurrenciesApi.md#list_budget_limit_by_currency) | **GET** /api/v1/currencies/{code}/budget_limits | List all budget limits with this currency
*FireflyIIIClient::CurrenciesApi* | [**list_currency**](docs/CurrenciesApi.md#list_currency) | **GET** /api/v1/currencies | List all currencies.
*FireflyIIIClient::CurrenciesApi* | [**list_exchange_rate_by_currency**](docs/CurrenciesApi.md#list_exchange_rate_by_currency) | **GET** /api/v1/currencies/{code}/cer | List all known exchange rates with (from or to) this currency.
*FireflyIIIClient::CurrenciesApi* | [**list_recurrence_by_currency**](docs/CurrenciesApi.md#list_recurrence_by_currency) | **GET** /api/v1/currencies/{code}/recurrences | List all recurring transactions with this currency.
*FireflyIIIClient::CurrenciesApi* | [**list_rule_by_currency**](docs/CurrenciesApi.md#list_rule_by_currency) | **GET** /api/v1/currencies/{code}/rules | List all rules with this currency.
*FireflyIIIClient::CurrenciesApi* | [**list_transaction_by_currency**](docs/CurrenciesApi.md#list_transaction_by_currency) | **GET** /api/v1/currencies/{code}/transactions | List all transactions with this currency.
*FireflyIIIClient::CurrenciesApi* | [**store_currency**](docs/CurrenciesApi.md#store_currency) | **POST** /api/v1/currencies | Store a new currency
*FireflyIIIClient::CurrenciesApi* | [**update_currency**](docs/CurrenciesApi.md#update_currency) | **PUT** /api/v1/currencies/{code} | Update existing currency.
*FireflyIIIClient::CurrencyExchangeRatesApi* | [**get_exchange_rate**](docs/CurrencyExchangeRatesApi.md#get_exchange_rate) | **GET** /api/v1/cer | Get an exchange rate.
*FireflyIIIClient::ImportApi* | [**get_import**](docs/ImportApi.md#get_import) | **GET** /api/v1/import/{key} | Show info on a single import
*FireflyIIIClient::ImportApi* | [**list_import**](docs/ImportApi.md#list_import) | **GET** /api/v1/import/list | List al imports
*FireflyIIIClient::ImportApi* | [**list_transaction_by_import**](docs/ImportApi.md#list_transaction_by_import) | **GET** /api/v1/import/{key}/transactions | List all transactions related to the import job. The correlation is made through the tag.
*FireflyIIIClient::LinksApi* | [**delete_link_type**](docs/LinksApi.md#delete_link_type) | **DELETE** /api/v1/link_types/{id} | Permanently delete link type.
*FireflyIIIClient::LinksApi* | [**delete_transaction_link**](docs/LinksApi.md#delete_transaction_link) | **DELETE** /api/v1/transaction_links/{id} | Permanently delete link between transactions.
*FireflyIIIClient::LinksApi* | [**get_link_type**](docs/LinksApi.md#get_link_type) | **GET** /api/v1/link_types/{id} | Get single a link type.
*FireflyIIIClient::LinksApi* | [**get_transaction_link**](docs/LinksApi.md#get_transaction_link) | **GET** /api/v1/transaction_links/{id} | Get a single link.
*FireflyIIIClient::LinksApi* | [**list_link_type**](docs/LinksApi.md#list_link_type) | **GET** /api/v1/link_types | List all types of links.
*FireflyIIIClient::LinksApi* | [**list_transaction_by_link_type**](docs/LinksApi.md#list_transaction_by_link_type) | **GET** /api/v1/link_types/{id}/transactions | List all transactions under this link type.
*FireflyIIIClient::LinksApi* | [**list_transaction_link**](docs/LinksApi.md#list_transaction_link) | **GET** /api/v1/transaction_links | List all transaction links.
*FireflyIIIClient::LinksApi* | [**store_link_type**](docs/LinksApi.md#store_link_type) | **POST** /api/v1/link_types | Create a new link type
*FireflyIIIClient::LinksApi* | [**store_transaction_link**](docs/LinksApi.md#store_transaction_link) | **POST** /api/v1/transaction_links | Create a new link between transactions
*FireflyIIIClient::LinksApi* | [**update_link_type**](docs/LinksApi.md#update_link_type) | **PUT** /api/v1/link_types/{id} | Update existing link type.
*FireflyIIIClient::LinksApi* | [**update_transaction_link**](docs/LinksApi.md#update_transaction_link) | **PUT** /api/v1/transaction_links/{id} | Update an existing link between transactions.
*FireflyIIIClient::PiggyBanksApi* | [**delete_piggy_bank**](docs/PiggyBanksApi.md#delete_piggy_bank) | **DELETE** /api/v1/piggy_banks/{id} | Delete a piggy bank.
*FireflyIIIClient::PiggyBanksApi* | [**get_piggy_bank**](docs/PiggyBanksApi.md#get_piggy_bank) | **GET** /api/v1/piggy_banks/{id} | Get a single piggy bank.
*FireflyIIIClient::PiggyBanksApi* | [**list_event_by_piggy_bank**](docs/PiggyBanksApi.md#list_event_by_piggy_bank) | **GET** /api/v1/piggy_banks/{id}/events | List all events linked to a piggy bank.
*FireflyIIIClient::PiggyBanksApi* | [**list_piggy_bank**](docs/PiggyBanksApi.md#list_piggy_bank) | **GET** /api/v1/piggy_banks | List all piggy banks.
*FireflyIIIClient::PiggyBanksApi* | [**store_piggy_bank**](docs/PiggyBanksApi.md#store_piggy_bank) | **POST** /api/v1/piggy_banks | Store a new piggy bank
*FireflyIIIClient::PiggyBanksApi* | [**update_piggy_bank**](docs/PiggyBanksApi.md#update_piggy_bank) | **PUT** /api/v1/piggy_banks/{id} | Update existing piggy bank.
*FireflyIIIClient::PreferencesApi* | [**get_preference**](docs/PreferencesApi.md#get_preference) | **GET** /api/v1/preferences/{name} | Return a single preference.
*FireflyIIIClient::PreferencesApi* | [**list_preference**](docs/PreferencesApi.md#list_preference) | **GET** /api/v1/preferences | List all users preferences.
*FireflyIIIClient::PreferencesApi* | [**update_preference**](docs/PreferencesApi.md#update_preference) | **PUT** /api/v1/preferences/{name} | Update preference
*FireflyIIIClient::RecurrencesApi* | [**delete_recurrence**](docs/RecurrencesApi.md#delete_recurrence) | **DELETE** /api/v1/recurrences/{id} | Delete a recurring transaction.
*FireflyIIIClient::RecurrencesApi* | [**get_recurrence**](docs/RecurrencesApi.md#get_recurrence) | **GET** /api/v1/recurrences/{id} | Get a single recurring transaction.
*FireflyIIIClient::RecurrencesApi* | [**list_recurrence**](docs/RecurrencesApi.md#list_recurrence) | **GET** /api/v1/recurrences | List all recurring transactions.
*FireflyIIIClient::RecurrencesApi* | [**list_transaction_by_recurrence**](docs/RecurrencesApi.md#list_transaction_by_recurrence) | **GET** /api/v1/recurrences/{id}/transactions | List all transactions created by a recurring transaction.
*FireflyIIIClient::RecurrencesApi* | [**store_recurrence**](docs/RecurrencesApi.md#store_recurrence) | **POST** /api/v1/recurrences | Store a new recurring transaction
*FireflyIIIClient::RecurrencesApi* | [**trigger_recurrence**](docs/RecurrencesApi.md#trigger_recurrence) | **POST** /api/v1/recurrences/trigger | Trigger the creation of recurring transactions (like a cron job).
*FireflyIIIClient::RecurrencesApi* | [**update_recurrence**](docs/RecurrencesApi.md#update_recurrence) | **PUT** /api/v1/recurrences/{id} | Update existing recurring transaction.
*FireflyIIIClient::RuleGroupsApi* | [**delete_rule_group**](docs/RuleGroupsApi.md#delete_rule_group) | **DELETE** /api/v1/rule_groups/{id} | Delete a rule group.
*FireflyIIIClient::RuleGroupsApi* | [**fire_rule_group**](docs/RuleGroupsApi.md#fire_rule_group) | **POST** /api/v1/rule_groups/{id}/trigger | Fire the rule group on your transactions.
*FireflyIIIClient::RuleGroupsApi* | [**get_rule_group**](docs/RuleGroupsApi.md#get_rule_group) | **GET** /api/v1/rule_groups/{id} | Get a single rule group.
*FireflyIIIClient::RuleGroupsApi* | [**list_rule_by_group**](docs/RuleGroupsApi.md#list_rule_by_group) | **GET** /api/v1/rule_groups/{id}/rules | List rules in this rule group.
*FireflyIIIClient::RuleGroupsApi* | [**list_rule_group**](docs/RuleGroupsApi.md#list_rule_group) | **GET** /api/v1/rule_groups | List all rule groups.
*FireflyIIIClient::RuleGroupsApi* | [**store_rule_group**](docs/RuleGroupsApi.md#store_rule_group) | **POST** /api/v1/rule_groups | Store a new rule group.
*FireflyIIIClient::RuleGroupsApi* | [**test_rule_group**](docs/RuleGroupsApi.md#test_rule_group) | **GET** /api/v1/rule_groups/{id}/test | Test which transactions would be hit by the rule group. No changes will be made.
*FireflyIIIClient::RuleGroupsApi* | [**update_rule_group**](docs/RuleGroupsApi.md#update_rule_group) | **PUT** /api/v1/rule_groups/{id} | Update existing rule group.
*FireflyIIIClient::RulesApi* | [**delete_rule**](docs/RulesApi.md#delete_rule) | **DELETE** /api/v1/rules/{id} | Delete an rule.
*FireflyIIIClient::RulesApi* | [**fire_rule**](docs/RulesApi.md#fire_rule) | **POST** /api/v1/rules/{id}/trigger | Fire the rule on your transactions.
*FireflyIIIClient::RulesApi* | [**get_rule**](docs/RulesApi.md#get_rule) | **GET** /api/v1/rules/{id} | Get a single rule.
*FireflyIIIClient::RulesApi* | [**list_rule**](docs/RulesApi.md#list_rule) | **GET** /api/v1/rules | List all rules.
*FireflyIIIClient::RulesApi* | [**store_rule**](docs/RulesApi.md#store_rule) | **POST** /api/v1/rules | Store a new rule
*FireflyIIIClient::RulesApi* | [**test_rule**](docs/RulesApi.md#test_rule) | **GET** /api/v1/rules/{id}/test | Test which transactions would be hit by the rule. No changes will be made.
*FireflyIIIClient::RulesApi* | [**update_rule**](docs/RulesApi.md#update_rule) | **PUT** /api/v1/rules/{id} | Update existing rule.
*FireflyIIIClient::SummaryApi* | [**get_basic_summary**](docs/SummaryApi.md#get_basic_summary) | **GET** /api/v1/summary/basic | Returns basic sums of the users data.
*FireflyIIIClient::TagsApi* | [**delete_tag**](docs/TagsApi.md#delete_tag) | **DELETE** /api/v1/tags/{tag} | Delete an tag.
*FireflyIIIClient::TagsApi* | [**get_tag**](docs/TagsApi.md#get_tag) | **GET** /api/v1/tags/{tag} | Get a single tag.
*FireflyIIIClient::TagsApi* | [**get_tag_cloud**](docs/TagsApi.md#get_tag_cloud) | **GET** /api/v1/tag-cloud | Returns a basic tag cloud.
*FireflyIIIClient::TagsApi* | [**list_tag**](docs/TagsApi.md#list_tag) | **GET** /api/v1/tags | List all tags.
*FireflyIIIClient::TagsApi* | [**list_transaction_by_tag**](docs/TagsApi.md#list_transaction_by_tag) | **GET** /api/v1/tags/{tag}/transactions | List all transactions with this tag.
*FireflyIIIClient::TagsApi* | [**store_tag**](docs/TagsApi.md#store_tag) | **POST** /api/v1/tags | Store a new tag
*FireflyIIIClient::TagsApi* | [**update_tag**](docs/TagsApi.md#update_tag) | **PUT** /api/v1/tags/{tag} | Update existing tag.
*FireflyIIIClient::TransactionsApi* | [**delete_transaction**](docs/TransactionsApi.md#delete_transaction) | **DELETE** /api/v1/transactions/{id} | Delete a transaction.
*FireflyIIIClient::TransactionsApi* | [**get_transaction**](docs/TransactionsApi.md#get_transaction) | **GET** /api/v1/transactions/{id} | Get a single transaction.
*FireflyIIIClient::TransactionsApi* | [**get_transaction_by_journal**](docs/TransactionsApi.md#get_transaction_by_journal) | **GET** /api/v1/transaction-journals/{id} | Get a single transaction, based on one of the underlying transaction journals.
*FireflyIIIClient::TransactionsApi* | [**list_attachment_by_transaction**](docs/TransactionsApi.md#list_attachment_by_transaction) | **GET** /api/v1/transactions/{id}/attachments | Lists all attachments.
*FireflyIIIClient::TransactionsApi* | [**list_event_by_transaction**](docs/TransactionsApi.md#list_event_by_transaction) | **GET** /api/v1/transactions/{id}/piggy_bank_events | Lists all piggy bank events.
*FireflyIIIClient::TransactionsApi* | [**list_transaction**](docs/TransactionsApi.md#list_transaction) | **GET** /api/v1/transactions | List all the user's transactions. 
*FireflyIIIClient::TransactionsApi* | [**store_transaction**](docs/TransactionsApi.md#store_transaction) | **POST** /api/v1/transactions | Store a new transaction
*FireflyIIIClient::TransactionsApi* | [**update_transaction**](docs/TransactionsApi.md#update_transaction) | **PUT** /api/v1/transactions/{id} | Update existing transaction.
*FireflyIIIClient::UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user) | **DELETE** /api/v1/users/{id} | Delete a user.
*FireflyIIIClient::UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /api/v1/users/{id} | Get a single user.
*FireflyIIIClient::UsersApi* | [**list_user**](docs/UsersApi.md#list_user) | **GET** /api/v1/users | List all users.
*FireflyIIIClient::UsersApi* | [**store_user**](docs/UsersApi.md#store_user) | **POST** /api/v1/users | Store a new user
*FireflyIIIClient::UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PUT** /api/v1/users/{id} | Update an existing user's information.


## Documentation for Models

 - [FireflyIIIClient::Account](docs/Account.md)
 - [FireflyIIIClient::AccountArray](docs/AccountArray.md)
 - [FireflyIIIClient::AccountRead](docs/AccountRead.md)
 - [FireflyIIIClient::AccountSingle](docs/AccountSingle.md)
 - [FireflyIIIClient::AccountTypeFilter](docs/AccountTypeFilter.md)
 - [FireflyIIIClient::AccountTypeProperty](docs/AccountTypeProperty.md)
 - [FireflyIIIClient::Attachment](docs/Attachment.md)
 - [FireflyIIIClient::AttachmentArray](docs/AttachmentArray.md)
 - [FireflyIIIClient::AttachmentRead](docs/AttachmentRead.md)
 - [FireflyIIIClient::AttachmentSingle](docs/AttachmentSingle.md)
 - [FireflyIIIClient::AvailableBudget](docs/AvailableBudget.md)
 - [FireflyIIIClient::AvailableBudgetArray](docs/AvailableBudgetArray.md)
 - [FireflyIIIClient::AvailableBudgetRead](docs/AvailableBudgetRead.md)
 - [FireflyIIIClient::AvailableBudgetSingle](docs/AvailableBudgetSingle.md)
 - [FireflyIIIClient::BasicSummaryEntry](docs/BasicSummaryEntry.md)
 - [FireflyIIIClient::Bill](docs/Bill.md)
 - [FireflyIIIClient::BillArray](docs/BillArray.md)
 - [FireflyIIIClient::BillPaidDates](docs/BillPaidDates.md)
 - [FireflyIIIClient::BillRead](docs/BillRead.md)
 - [FireflyIIIClient::BillSingle](docs/BillSingle.md)
 - [FireflyIIIClient::Budget](docs/Budget.md)
 - [FireflyIIIClient::BudgetArray](docs/BudgetArray.md)
 - [FireflyIIIClient::BudgetLimit](docs/BudgetLimit.md)
 - [FireflyIIIClient::BudgetLimitArray](docs/BudgetLimitArray.md)
 - [FireflyIIIClient::BudgetLimitRead](docs/BudgetLimitRead.md)
 - [FireflyIIIClient::BudgetLimitSingle](docs/BudgetLimitSingle.md)
 - [FireflyIIIClient::BudgetRead](docs/BudgetRead.md)
 - [FireflyIIIClient::BudgetSingle](docs/BudgetSingle.md)
 - [FireflyIIIClient::BudgetSpent](docs/BudgetSpent.md)
 - [FireflyIIIClient::Category](docs/Category.md)
 - [FireflyIIIClient::CategoryArray](docs/CategoryArray.md)
 - [FireflyIIIClient::CategoryEarned](docs/CategoryEarned.md)
 - [FireflyIIIClient::CategoryRead](docs/CategoryRead.md)
 - [FireflyIIIClient::CategorySingle](docs/CategorySingle.md)
 - [FireflyIIIClient::CategorySpent](docs/CategorySpent.md)
 - [FireflyIIIClient::ChartDataPoint](docs/ChartDataPoint.md)
 - [FireflyIIIClient::ChartDataSet](docs/ChartDataSet.md)
 - [FireflyIIIClient::ConfigurationUpdate](docs/ConfigurationUpdate.md)
 - [FireflyIIIClient::Currency](docs/Currency.md)
 - [FireflyIIIClient::CurrencyArray](docs/CurrencyArray.md)
 - [FireflyIIIClient::CurrencyRead](docs/CurrencyRead.md)
 - [FireflyIIIClient::CurrencySingle](docs/CurrencySingle.md)
 - [FireflyIIIClient::ExchangeRate](docs/ExchangeRate.md)
 - [FireflyIIIClient::ExchangeRateArray](docs/ExchangeRateArray.md)
 - [FireflyIIIClient::ExchangeRateAttributes](docs/ExchangeRateAttributes.md)
 - [FireflyIIIClient::ImportJob](docs/ImportJob.md)
 - [FireflyIIIClient::ImportJobArray](docs/ImportJobArray.md)
 - [FireflyIIIClient::ImportJobAttributes](docs/ImportJobAttributes.md)
 - [FireflyIIIClient::ImportJobSingle](docs/ImportJobSingle.md)
 - [FireflyIIIClient::LinkType](docs/LinkType.md)
 - [FireflyIIIClient::LinkTypeArray](docs/LinkTypeArray.md)
 - [FireflyIIIClient::LinkTypeRead](docs/LinkTypeRead.md)
 - [FireflyIIIClient::LinkTypeSingle](docs/LinkTypeSingle.md)
 - [FireflyIIIClient::Meta](docs/Meta.md)
 - [FireflyIIIClient::MetaPagination](docs/MetaPagination.md)
 - [FireflyIIIClient::ObjectLink](docs/ObjectLink.md)
 - [FireflyIIIClient::ObjectLink0](docs/ObjectLink0.md)
 - [FireflyIIIClient::PageLink](docs/PageLink.md)
 - [FireflyIIIClient::PiggyBank](docs/PiggyBank.md)
 - [FireflyIIIClient::PiggyBankArray](docs/PiggyBankArray.md)
 - [FireflyIIIClient::PiggyBankEvent](docs/PiggyBankEvent.md)
 - [FireflyIIIClient::PiggyBankEventArray](docs/PiggyBankEventArray.md)
 - [FireflyIIIClient::PiggyBankEventAttributes](docs/PiggyBankEventAttributes.md)
 - [FireflyIIIClient::PiggyBankRead](docs/PiggyBankRead.md)
 - [FireflyIIIClient::PiggyBankSingle](docs/PiggyBankSingle.md)
 - [FireflyIIIClient::Preference](docs/Preference.md)
 - [FireflyIIIClient::PreferenceArray](docs/PreferenceArray.md)
 - [FireflyIIIClient::PreferenceRead](docs/PreferenceRead.md)
 - [FireflyIIIClient::PreferenceSingle](docs/PreferenceSingle.md)
 - [FireflyIIIClient::Recurrence](docs/Recurrence.md)
 - [FireflyIIIClient::RecurrenceArray](docs/RecurrenceArray.md)
 - [FireflyIIIClient::RecurrenceRead](docs/RecurrenceRead.md)
 - [FireflyIIIClient::RecurrenceRepetition](docs/RecurrenceRepetition.md)
 - [FireflyIIIClient::RecurrenceSingle](docs/RecurrenceSingle.md)
 - [FireflyIIIClient::RecurrenceTransaction](docs/RecurrenceTransaction.md)
 - [FireflyIIIClient::Rule](docs/Rule.md)
 - [FireflyIIIClient::RuleAction](docs/RuleAction.md)
 - [FireflyIIIClient::RuleArray](docs/RuleArray.md)
 - [FireflyIIIClient::RuleGroup](docs/RuleGroup.md)
 - [FireflyIIIClient::RuleGroupArray](docs/RuleGroupArray.md)
 - [FireflyIIIClient::RuleGroupRead](docs/RuleGroupRead.md)
 - [FireflyIIIClient::RuleGroupSingle](docs/RuleGroupSingle.md)
 - [FireflyIIIClient::RuleRead](docs/RuleRead.md)
 - [FireflyIIIClient::RuleSingle](docs/RuleSingle.md)
 - [FireflyIIIClient::RuleTrigger](docs/RuleTrigger.md)
 - [FireflyIIIClient::SystemConfiguration](docs/SystemConfiguration.md)
 - [FireflyIIIClient::SystemConfigurationData](docs/SystemConfigurationData.md)
 - [FireflyIIIClient::SystemInfo](docs/SystemInfo.md)
 - [FireflyIIIClient::SystemInfoData](docs/SystemInfoData.md)
 - [FireflyIIIClient::TagArray](docs/TagArray.md)
 - [FireflyIIIClient::TagCloud](docs/TagCloud.md)
 - [FireflyIIIClient::TagCloudTag](docs/TagCloudTag.md)
 - [FireflyIIIClient::TagModel](docs/TagModel.md)
 - [FireflyIIIClient::TagRead](docs/TagRead.md)
 - [FireflyIIIClient::TagSingle](docs/TagSingle.md)
 - [FireflyIIIClient::Transaction](docs/Transaction.md)
 - [FireflyIIIClient::TransactionArray](docs/TransactionArray.md)
 - [FireflyIIIClient::TransactionLink](docs/TransactionLink.md)
 - [FireflyIIIClient::TransactionLinkArray](docs/TransactionLinkArray.md)
 - [FireflyIIIClient::TransactionLinkRead](docs/TransactionLinkRead.md)
 - [FireflyIIIClient::TransactionLinkSingle](docs/TransactionLinkSingle.md)
 - [FireflyIIIClient::TransactionRead](docs/TransactionRead.md)
 - [FireflyIIIClient::TransactionSingle](docs/TransactionSingle.md)
 - [FireflyIIIClient::TransactionSplit](docs/TransactionSplit.md)
 - [FireflyIIIClient::TransactionTypeFilter](docs/TransactionTypeFilter.md)
 - [FireflyIIIClient::User](docs/User.md)
 - [FireflyIIIClient::UserArray](docs/UserArray.md)
 - [FireflyIIIClient::UserRead](docs/UserRead.md)
 - [FireflyIIIClient::UserSingle](docs/UserSingle.md)
 - [FireflyIIIClient::ValidationError](docs/ValidationError.md)
 - [FireflyIIIClient::ValidationErrorErrors](docs/ValidationErrorErrors.md)


## Documentation for Authorization


### firefly_iii_auth


- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://demo.firefly-iii.org/oauth/authorize
- **Scopes**: N/A

