# FireflyIIIClient::AccountsApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_account**](AccountsApi.md#delete_account) | **DELETE** /api/v1/accounts/{id} | Permanently delete account. |
| [**get_account**](AccountsApi.md#get_account) | **GET** /api/v1/accounts/{id} | Get single account. |
| [**list_account**](AccountsApi.md#list_account) | **GET** /api/v1/accounts | List all accounts. |
| [**list_piggy_bank_by_account**](AccountsApi.md#list_piggy_bank_by_account) | **GET** /api/v1/accounts/{id}/piggy_banks | List all piggy banks related to the account. |
| [**list_transaction_by_account**](AccountsApi.md#list_transaction_by_account) | **GET** /api/v1/accounts/{id}/transactions | List all transactions related to the account. |
| [**store_account**](AccountsApi.md#store_account) | **POST** /api/v1/accounts | Create new account. |
| [**update_account**](AccountsApi.md#update_account) | **PUT** /api/v1/accounts/{id} | Update existing account. |


## delete_account

> delete_account(id)

Permanently delete account.

Will permanently delete an account. Any associated transactions and piggy banks are ALSO deleted. Cannot be recovered from. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AccountsApi.new
id = 1 # Integer | The ID of the account.

begin
  # Permanently delete account.
  api_instance.delete_account(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->delete_account: #{e}"
end
```

#### Using the delete_account_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_account_with_http_info(id)

```ruby

begin
  # Permanently delete account.
  data, status_code, headers = api_instance.delete_account_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->delete_account_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the account. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_account

> <AccountSingle> get_account(id, opts)

Get single account.

Returns a single account by its ID. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AccountsApi.new
id = 1 # Integer | The ID of the account.
opts = {
  date: Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. When added to the request, Firefly III will show the account's balance on that day. 
}

begin
  # Get single account.
  result = api_instance.get_account(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->get_account: #{e}"
end
```

#### Using the get_account_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AccountSingle>, Integer, Hash)> get_account_with_http_info(id, opts)

```ruby

begin
  # Get single account.
  data, status_code, headers = api_instance.get_account_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AccountSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->get_account_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the account. |  |
| **date** | **Date** | A date formatted YYYY-MM-DD. When added to the request, Firefly III will show the account&#39;s balance on that day.  | [optional] |

### Return type

[**AccountSingle**](AccountSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_account

> <AccountArray> list_account(opts)

List all accounts.

This endpoint returns a list of all the accounts owned by the authenticated user. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AccountsApi.new
opts = {
  page: 1, # Integer | Page number. The default pagination is per 50 items.
  date: Date.parse('2013-10-20'), # Date | A date formatted YYYY-MM-DD. When added to the request, Firefly III will show the account's balance on that day. 
  type: FireflyIIIClient::AccountTypeFilter::ALL # AccountTypeFilter | Optional filter on the account type(s) returned
}

begin
  # List all accounts.
  result = api_instance.list_account(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->list_account: #{e}"
end
```

#### Using the list_account_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AccountArray>, Integer, Hash)> list_account_with_http_info(opts)

```ruby

begin
  # List all accounts.
  data, status_code, headers = api_instance.list_account_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AccountArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->list_account_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is per 50 items. | [optional] |
| **date** | **Date** | A date formatted YYYY-MM-DD. When added to the request, Firefly III will show the account&#39;s balance on that day.  | [optional] |
| **type** | [**AccountTypeFilter**](.md) | Optional filter on the account type(s) returned | [optional] |

### Return type

[**AccountArray**](AccountArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_piggy_bank_by_account

> <PiggyBankArray> list_piggy_bank_by_account(id, opts)

List all piggy banks related to the account.

This endpoint returns a list of all the piggy banks connected to the account. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AccountsApi.new
id = 1 # Integer | The ID of the account.
opts = {
  page: 56 # Integer | Page number. The default pagination is per 50 items.
}

begin
  # List all piggy banks related to the account.
  result = api_instance.list_piggy_bank_by_account(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->list_piggy_bank_by_account: #{e}"
end
```

#### Using the list_piggy_bank_by_account_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<PiggyBankArray>, Integer, Hash)> list_piggy_bank_by_account_with_http_info(id, opts)

```ruby

begin
  # List all piggy banks related to the account.
  data, status_code, headers = api_instance.list_piggy_bank_by_account_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <PiggyBankArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->list_piggy_bank_by_account_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the account. |  |
| **page** | **Integer** | Page number. The default pagination is per 50 items. | [optional] |

### Return type

[**PiggyBankArray**](PiggyBankArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction_by_account

> <TransactionArray> list_transaction_by_account(id, opts)

List all transactions related to the account.

This endpoint returns a list of all the transactions connected to the account. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AccountsApi.new
id = 1 # Integer | The ID of the account.
opts = {
  page: 1, # Integer | Page number. The default pagination is per 50 items.
  limit: 5, # Integer | Limits the number of results on one page.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. 
  _end: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. 
  type: FireflyIIIClient::TransactionTypeFilter::ALL # TransactionTypeFilter | Optional filter on the transaction type(s) returned.
}

begin
  # List all transactions related to the account.
  result = api_instance.list_transaction_by_account(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->list_transaction_by_account: #{e}"
end
```

#### Using the list_transaction_by_account_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> list_transaction_by_account_with_http_info(id, opts)

```ruby

begin
  # List all transactions related to the account.
  data, status_code, headers = api_instance.list_transaction_by_account_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->list_transaction_by_account_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the account. |  |
| **page** | **Integer** | Page number. The default pagination is per 50 items. | [optional] |
| **limit** | **Integer** | Limits the number of results on one page. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD.  | [optional] |
| **type** | [**TransactionTypeFilter**](.md) | Optional filter on the transaction type(s) returned. | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_account

> <AccountSingle> store_account(account)

Create new account.

Creates a new account. The data required can be submitted as a JSON body or as a list of parameters (in key=value pairs, like a webform).

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AccountsApi.new
account = FireflyIIIClient::Account.new({ name: 'My checking account', type: 'asset', account_role: 'defaultAsset' }) # Account | JSON array with the necessary account information or key=value pairs. See the model for the exact specifications.

begin
  # Create new account.
  result = api_instance.store_account(account)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->store_account: #{e}"
end
```

#### Using the store_account_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AccountSingle>, Integer, Hash)> store_account_with_http_info(account)

```ruby

begin
  # Create new account.
  data, status_code, headers = api_instance.store_account_with_http_info(account)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AccountSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->store_account_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **account** | [**Account**](Account.md) | JSON array with the necessary account information or key&#x3D;value pairs. See the model for the exact specifications. |  |

### Return type

[**AccountSingle**](AccountSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_account

> <AccountSingle> update_account(id, account)

Update existing account.

Used to update a single account. All fields that are not submitted will be cleared (set to NULL). The model will tell you which fields are mandatory. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AccountsApi.new
id = 1 # Integer | The ID of the account.
account = FireflyIIIClient::Account.new({ name: 'My checking account', type: 'asset', account_role: 'defaultAsset' }) # Account | JSON array or formdata with updated account information. See the model for the exact specifications.

begin
  # Update existing account.
  result = api_instance.update_account(id, account)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->update_account: #{e}"
end
```

#### Using the update_account_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AccountSingle>, Integer, Hash)> update_account_with_http_info(id, account)

```ruby

begin
  # Update existing account.
  data, status_code, headers = api_instance.update_account_with_http_info(id, account)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AccountSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AccountsApi->update_account_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the account. |  |
| **account** | [**Account**](Account.md) | JSON array or formdata with updated account information. See the model for the exact specifications. |  |

### Return type

[**AccountSingle**](AccountSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

