# FireflyIIIClient::AttachmentsApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_attachment**](AttachmentsApi.md#delete_attachment) | **DELETE** /api/v1/attachments/{id} | Delete an attachment. |
| [**download_attachment**](AttachmentsApi.md#download_attachment) | **GET** /api/v1/attachments/{id}/download | Download a single attachment. |
| [**get_attachment**](AttachmentsApi.md#get_attachment) | **GET** /api/v1/attachments/{id} | Get a single attachment. |
| [**list_attachment**](AttachmentsApi.md#list_attachment) | **GET** /api/v1/attachments | List all attachments. |
| [**store_attachment**](AttachmentsApi.md#store_attachment) | **POST** /api/v1/attachments | Store a new attachment. |
| [**update_attachment**](AttachmentsApi.md#update_attachment) | **PUT** /api/v1/attachments/{id} | Update existing attachment. |
| [**upload_attachment**](AttachmentsApi.md#upload_attachment) | **POST** /api/v1/attachments/{id}/upload | Upload an attachment. |


## delete_attachment

> delete_attachment(id)

Delete an attachment.

With this endpoint you delete an attachment, including any stored file data. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AttachmentsApi.new
id = 1 # Integer | The ID of the single.

begin
  # Delete an attachment.
  api_instance.delete_attachment(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->delete_attachment: #{e}"
end
```

#### Using the delete_attachment_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_attachment_with_http_info(id)

```ruby

begin
  # Delete an attachment.
  data, status_code, headers = api_instance.delete_attachment_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->delete_attachment_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the single. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## download_attachment

> File download_attachment(id)

Download a single attachment.

This endpoint allows you to download the binary content of a transaction. It will be sent to you as a download, using the content type \"application/octet-stream\" and content disposition \"attachment; filename=example.pdf\". 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AttachmentsApi.new
id = 1 # Integer | The ID of the attachment.

begin
  # Download a single attachment.
  result = api_instance.download_attachment(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->download_attachment: #{e}"
end
```

#### Using the download_attachment_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(File, Integer, Hash)> download_attachment_with_http_info(id)

```ruby

begin
  # Download a single attachment.
  data, status_code, headers = api_instance.download_attachment_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => File
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->download_attachment_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the attachment. |  |

### Return type

**File**

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/octet-stream


## get_attachment

> <AttachmentSingle> get_attachment(id)

Get a single attachment.

Get a single attachment. This endpoint only returns the available metadata for the attachment. Actual file data is handled in two other endpoints (see below). 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AttachmentsApi.new
id = 1 # Integer | The ID of the attachment.

begin
  # Get a single attachment.
  result = api_instance.get_attachment(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->get_attachment: #{e}"
end
```

#### Using the get_attachment_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AttachmentSingle>, Integer, Hash)> get_attachment_with_http_info(id)

```ruby

begin
  # Get a single attachment.
  data, status_code, headers = api_instance.get_attachment_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AttachmentSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->get_attachment_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the attachment. |  |

### Return type

[**AttachmentSingle**](AttachmentSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_attachment

> <AttachmentArray> list_attachment(opts)

List all attachments.

This endpoint lists all attachments. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AttachmentsApi.new
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # List all attachments.
  result = api_instance.list_attachment(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->list_attachment: #{e}"
end
```

#### Using the list_attachment_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AttachmentArray>, Integer, Hash)> list_attachment_with_http_info(opts)

```ruby

begin
  # List all attachments.
  data, status_code, headers = api_instance.list_attachment_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AttachmentArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->list_attachment_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**AttachmentArray**](AttachmentArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_attachment

> <AttachmentSingle> store_attachment(attachment)

Store a new attachment.

Creates a new attachment. The data required can be submitted as a JSON body or as a list of parameters. You cannot use this endpoint to upload the actual file data (see below). This endpoint only creates the attachment object. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AttachmentsApi.new
attachment = FireflyIIIClient::Attachment.new({ filename: 'file.pdf', model: 'Bill', model_id: 134 }) # Attachment | JSON array or key=value pairs with the necessary attachment information. See the model for the exact specifications.

begin
  # Store a new attachment.
  result = api_instance.store_attachment(attachment)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->store_attachment: #{e}"
end
```

#### Using the store_attachment_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AttachmentSingle>, Integer, Hash)> store_attachment_with_http_info(attachment)

```ruby

begin
  # Store a new attachment.
  data, status_code, headers = api_instance.store_attachment_with_http_info(attachment)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AttachmentSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->store_attachment_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **attachment** | [**Attachment**](Attachment.md) | JSON array or key&#x3D;value pairs with the necessary attachment information. See the model for the exact specifications. |  |

### Return type

[**AttachmentSingle**](AttachmentSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_attachment

> <AttachmentSingle> update_attachment(id, attachment)

Update existing attachment.

Update the meta data for an existing attachment. This endpoint does not allow you to upload or download data. For that, see below. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AttachmentsApi.new
id = 1 # Integer | The ID of the attachment.
attachment = FireflyIIIClient::Attachment.new({ filename: 'file.pdf', model: 'Bill', model_id: 134 }) # Attachment | JSON array with updated attachment information. See the model for the exact specifications.

begin
  # Update existing attachment.
  result = api_instance.update_attachment(id, attachment)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->update_attachment: #{e}"
end
```

#### Using the update_attachment_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AttachmentSingle>, Integer, Hash)> update_attachment_with_http_info(id, attachment)

```ruby

begin
  # Update existing attachment.
  data, status_code, headers = api_instance.update_attachment_with_http_info(id, attachment)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AttachmentSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->update_attachment_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the attachment. |  |
| **attachment** | [**Attachment**](Attachment.md) | JSON array with updated attachment information. See the model for the exact specifications. |  |

### Return type

[**AttachmentSingle**](AttachmentSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## upload_attachment

> upload_attachment(id, opts)

Upload an attachment.

Use this endpoint to upload (and possible overwrite) the file contents of an attachment. Simply put the entire file in the body as binary data. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AttachmentsApi.new
id = 1 # Integer | The ID of the attachment.
opts = {
  body: File.new('/path/to/some/file') # File | 
}

begin
  # Upload an attachment.
  api_instance.upload_attachment(id, opts)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->upload_attachment: #{e}"
end
```

#### Using the upload_attachment_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> upload_attachment_with_http_info(id, opts)

```ruby

begin
  # Upload an attachment.
  data, status_code, headers = api_instance.upload_attachment_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AttachmentsApi->upload_attachment_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the attachment. |  |
| **body** | **File** |  | [optional] |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/octet-stream
- **Accept**: Not defined

