# FireflyIIIClient::AvailableBudgetsApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_available_budget**](AvailableBudgetsApi.md#delete_available_budget) | **DELETE** /api/v1/available_budgets/{id} | Delete an available budget. |
| [**get_available_budget**](AvailableBudgetsApi.md#get_available_budget) | **GET** /api/v1/available_budgets/{id} | Get a single available budget. |
| [**list_available_budget**](AvailableBudgetsApi.md#list_available_budget) | **GET** /api/v1/available_budgets | List all available budget amounts. |
| [**store_available_budget**](AvailableBudgetsApi.md#store_available_budget) | **POST** /api/v1/available_budgets | Store a new available budget |
| [**update_available_budget**](AvailableBudgetsApi.md#update_available_budget) | **PUT** /api/v1/available_budgets/{id} | Update existing available budget, to change for example the date range of the amount or the amount itself. |


## delete_available_budget

> delete_available_budget(id)

Delete an available budget.

Delete an available budget. Not much more to say.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AvailableBudgetsApi.new
id = 1 # Integer | The ID of the available budget.

begin
  # Delete an available budget.
  api_instance.delete_available_budget(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AvailableBudgetsApi->delete_available_budget: #{e}"
end
```

#### Using the delete_available_budget_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_available_budget_with_http_info(id)

```ruby

begin
  # Delete an available budget.
  data, status_code, headers = api_instance.delete_available_budget_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AvailableBudgetsApi->delete_available_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the available budget. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_available_budget

> <AvailableBudgetSingle> get_available_budget(id)

Get a single available budget.

Get a single available budget, by ID.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AvailableBudgetsApi.new
id = 1 # Integer | The ID of the available budget.

begin
  # Get a single available budget.
  result = api_instance.get_available_budget(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AvailableBudgetsApi->get_available_budget: #{e}"
end
```

#### Using the get_available_budget_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AvailableBudgetSingle>, Integer, Hash)> get_available_budget_with_http_info(id)

```ruby

begin
  # Get a single available budget.
  data, status_code, headers = api_instance.get_available_budget_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AvailableBudgetSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AvailableBudgetsApi->get_available_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the available budget. |  |

### Return type

[**AvailableBudgetSingle**](AvailableBudgetSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_available_budget

> <AvailableBudgetArray> list_available_budget(opts)

List all available budget amounts.

Firefly III allows users to set the amount that is available to be budgeted in so-called \"available budgets\". For example, the user could have 1200,- available to be divided during the coming month. This amount is used on the /budgets page. This endpoint returns all of these amounts and the periods for which they are set. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AvailableBudgetsApi.new
opts = {
  page: 1, # Integer | Page number. The default pagination is 50.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. 
  _end: Date.parse('Mon Dec 31 00:00:00 GMT 2018') # Date | A date formatted YYYY-MM-DD. 
}

begin
  # List all available budget amounts.
  result = api_instance.list_available_budget(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AvailableBudgetsApi->list_available_budget: #{e}"
end
```

#### Using the list_available_budget_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AvailableBudgetArray>, Integer, Hash)> list_available_budget_with_http_info(opts)

```ruby

begin
  # List all available budget amounts.
  data, status_code, headers = api_instance.list_available_budget_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AvailableBudgetArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AvailableBudgetsApi->list_available_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD.  | [optional] |

### Return type

[**AvailableBudgetArray**](AvailableBudgetArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_available_budget

> <AvailableBudgetSingle> store_available_budget(available_budget)

Store a new available budget

Creates a new available budget for a specified period. The data required can be submitted as a JSON body or as a list of parameters. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AvailableBudgetsApi.new
available_budget = FireflyIIIClient::AvailableBudget.new({ amount: 250, start: Date.parse('Sun Sep 17 00:00:00 GMT 2017'), _end: Date.parse('Sun Sep 17 00:00:00 GMT 2017') }) # AvailableBudget | JSON array or key=value pairs with the necessary available budget information. See the model for the exact specifications.

begin
  # Store a new available budget
  result = api_instance.store_available_budget(available_budget)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AvailableBudgetsApi->store_available_budget: #{e}"
end
```

#### Using the store_available_budget_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AvailableBudgetSingle>, Integer, Hash)> store_available_budget_with_http_info(available_budget)

```ruby

begin
  # Store a new available budget
  data, status_code, headers = api_instance.store_available_budget_with_http_info(available_budget)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AvailableBudgetSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AvailableBudgetsApi->store_available_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **available_budget** | [**AvailableBudget**](AvailableBudget.md) | JSON array or key&#x3D;value pairs with the necessary available budget information. See the model for the exact specifications. |  |

### Return type

[**AvailableBudgetSingle**](AvailableBudgetSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_available_budget

> <AvailableBudgetSingle> update_available_budget(id, available_budget)

Update existing available budget, to change for example the date range of the amount or the amount itself.

Update existing available budget.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::AvailableBudgetsApi.new
id = 1 # Integer | The ID of the object.X
available_budget = FireflyIIIClient::AvailableBudget.new({ amount: 250, start: Date.parse('Sun Sep 17 00:00:00 GMT 2017'), _end: Date.parse('Sun Sep 17 00:00:00 GMT 2017') }) # AvailableBudget | JSON array or form value with updated available budget information. See the model for the exact specifications.

begin
  # Update existing available budget, to change for example the date range of the amount or the amount itself.
  result = api_instance.update_available_budget(id, available_budget)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AvailableBudgetsApi->update_available_budget: #{e}"
end
```

#### Using the update_available_budget_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AvailableBudgetSingle>, Integer, Hash)> update_available_budget_with_http_info(id, available_budget)

```ruby

begin
  # Update existing available budget, to change for example the date range of the amount or the amount itself.
  data, status_code, headers = api_instance.update_available_budget_with_http_info(id, available_budget)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AvailableBudgetSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling AvailableBudgetsApi->update_available_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the object.X |  |
| **available_budget** | [**AvailableBudget**](AvailableBudget.md) | JSON array or form value with updated available budget information. See the model for the exact specifications. |  |

### Return type

[**AvailableBudgetSingle**](AvailableBudgetSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

