# FireflyIIIClient::BillsApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_bill**](BillsApi.md#delete_bill) | **DELETE** /api/v1/bills/{id} | Delete a bill. |
| [**get_bill**](BillsApi.md#get_bill) | **GET** /api/v1/bills/{id} | Get a single bill. |
| [**list_attachment_by_bill**](BillsApi.md#list_attachment_by_bill) | **GET** /api/v1/bills/{id}/attachments | List all attachments uploaded to the bill. |
| [**list_bill**](BillsApi.md#list_bill) | **GET** /api/v1/bills | List all bills. |
| [**list_rule_by_bill**](BillsApi.md#list_rule_by_bill) | **GET** /api/v1/bills/{id}/rules | List all rules associated with the bill. |
| [**list_transaction_by_bill**](BillsApi.md#list_transaction_by_bill) | **GET** /api/v1/bills/{id}/transactions | List all transactions associated with the  bill. |
| [**store_bill**](BillsApi.md#store_bill) | **POST** /api/v1/bills | Store a new bill |
| [**update_bill**](BillsApi.md#update_bill) | **PUT** /api/v1/bills/{id} | Update existing bill. |


## delete_bill

> delete_bill(id)

Delete a bill.

Delete a bill. This will not delete any associated rules. Will not remove associated transactions. WILL remove all associated attachments.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BillsApi.new
id = 1 # Integer | The ID of the bill.

begin
  # Delete a bill.
  api_instance.delete_bill(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->delete_bill: #{e}"
end
```

#### Using the delete_bill_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_bill_with_http_info(id)

```ruby

begin
  # Delete a bill.
  data, status_code, headers = api_instance.delete_bill_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->delete_bill_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the bill. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_bill

> <BillSingle> get_bill(id, opts)

Get a single bill.

Get a single bill.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BillsApi.new
id = 1 # Integer | The ID of the bill.
opts = {
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. If it is are added to the request, Firefly III will calculate the appropriate payment and paid dates. 
  _end: Date.parse('Mon Dec 31 00:00:00 GMT 2018') # Date | A date formatted YYYY-MM-DD. If it is added to the request, Firefly III will calculate the appropriate payment and paid dates. 
}

begin
  # Get a single bill.
  result = api_instance.get_bill(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->get_bill: #{e}"
end
```

#### Using the get_bill_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BillSingle>, Integer, Hash)> get_bill_with_http_info(id, opts)

```ruby

begin
  # Get a single bill.
  data, status_code, headers = api_instance.get_bill_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BillSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->get_bill_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the bill. |  |
| **start** | **Date** | A date formatted YYYY-MM-DD. If it is are added to the request, Firefly III will calculate the appropriate payment and paid dates.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD. If it is added to the request, Firefly III will calculate the appropriate payment and paid dates.  | [optional] |

### Return type

[**BillSingle**](BillSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_attachment_by_bill

> <AttachmentArray> list_attachment_by_bill(id, opts)

List all attachments uploaded to the bill.

This endpoint will list all attachments linked to the bill.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BillsApi.new
id = 1 # Integer | The ID of the bill.
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # List all attachments uploaded to the bill.
  result = api_instance.list_attachment_by_bill(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->list_attachment_by_bill: #{e}"
end
```

#### Using the list_attachment_by_bill_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AttachmentArray>, Integer, Hash)> list_attachment_by_bill_with_http_info(id, opts)

```ruby

begin
  # List all attachments uploaded to the bill.
  data, status_code, headers = api_instance.list_attachment_by_bill_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AttachmentArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->list_attachment_by_bill_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the bill. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**AttachmentArray**](AttachmentArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_bill

> <BillArray> list_bill(opts)

List all bills.

This endpoint will list all the user's bills.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BillsApi.new
opts = {
  page: 1, # Integer | Page number. The default pagination is 50.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. If it is are added to the request, Firefly III will calculate the appropriate payment and paid dates. 
  _end: Date.parse('Mon Dec 31 00:00:00 GMT 2018') # Date | A date formatted YYYY-MM-DD. If it is added to the request, Firefly III will calculate the appropriate payment and paid dates. 
}

begin
  # List all bills.
  result = api_instance.list_bill(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->list_bill: #{e}"
end
```

#### Using the list_bill_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BillArray>, Integer, Hash)> list_bill_with_http_info(opts)

```ruby

begin
  # List all bills.
  data, status_code, headers = api_instance.list_bill_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BillArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->list_bill_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD. If it is are added to the request, Firefly III will calculate the appropriate payment and paid dates.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD. If it is added to the request, Firefly III will calculate the appropriate payment and paid dates.  | [optional] |

### Return type

[**BillArray**](BillArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_rule_by_bill

> <RuleArray> list_rule_by_bill(id)

List all rules associated with the bill.

This endpoint will list all rules that have an action to set the bill to this bill.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BillsApi.new
id = 1 # Integer | The ID of the bill.

begin
  # List all rules associated with the bill.
  result = api_instance.list_rule_by_bill(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->list_rule_by_bill: #{e}"
end
```

#### Using the list_rule_by_bill_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RuleArray>, Integer, Hash)> list_rule_by_bill_with_http_info(id)

```ruby

begin
  # List all rules associated with the bill.
  data, status_code, headers = api_instance.list_rule_by_bill_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RuleArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->list_rule_by_bill_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the bill. |  |

### Return type

[**RuleArray**](RuleArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction_by_bill

> <TransactionArray> list_transaction_by_bill(id, opts)

List all transactions associated with the  bill.

This endpoint will list all transactions linked to this bill.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BillsApi.new
id = 1 # Integer | The ID of the bill.
opts = {
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. 
  _end: Date.parse('Mon Dec 31 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. 
  type: FireflyIIIClient::TransactionTypeFilter::ALL # TransactionTypeFilter | Optional filter on the transaction type(s) returned
}

begin
  # List all transactions associated with the  bill.
  result = api_instance.list_transaction_by_bill(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->list_transaction_by_bill: #{e}"
end
```

#### Using the list_transaction_by_bill_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> list_transaction_by_bill_with_http_info(id, opts)

```ruby

begin
  # List all transactions associated with the  bill.
  data, status_code, headers = api_instance.list_transaction_by_bill_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->list_transaction_by_bill_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the bill. |  |
| **start** | **Date** | A date formatted YYYY-MM-DD.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD.  | [optional] |
| **type** | [**TransactionTypeFilter**](.md) | Optional filter on the transaction type(s) returned | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_bill

> <BillSingle> store_bill(bill)

Store a new bill

Creates a new bill. The data required can be submitted as a JSON body or as a list of parameters.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BillsApi.new
bill = FireflyIIIClient::Bill.new({ name: 'Rent', amount_min: 600, amount_max: 601, date: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), repeat_freq: 'weekly' }) # Bill | JSON array or key=value pairs with the necessary bill information. See the model for the exact specifications.

begin
  # Store a new bill
  result = api_instance.store_bill(bill)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->store_bill: #{e}"
end
```

#### Using the store_bill_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BillSingle>, Integer, Hash)> store_bill_with_http_info(bill)

```ruby

begin
  # Store a new bill
  data, status_code, headers = api_instance.store_bill_with_http_info(bill)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BillSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->store_bill_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **bill** | [**Bill**](Bill.md) | JSON array or key&#x3D;value pairs with the necessary bill information. See the model for the exact specifications. |  |

### Return type

[**BillSingle**](BillSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_bill

> <BillSingle> update_bill(id, bill)

Update existing bill.

Update existing bill.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BillsApi.new
id = 1 # Integer | The ID of the bill.
bill = FireflyIIIClient::Bill.new({ name: 'Rent', amount_min: 600, amount_max: 601, date: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), repeat_freq: 'weekly' }) # Bill | JSON array or key=value pairs with updated bill information. See the model for the exact specifications.

begin
  # Update existing bill.
  result = api_instance.update_bill(id, bill)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->update_bill: #{e}"
end
```

#### Using the update_bill_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BillSingle>, Integer, Hash)> update_bill_with_http_info(id, bill)

```ruby

begin
  # Update existing bill.
  data, status_code, headers = api_instance.update_bill_with_http_info(id, bill)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BillSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BillsApi->update_bill_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the bill. |  |
| **bill** | [**Bill**](Bill.md) | JSON array or key&#x3D;value pairs with updated bill information. See the model for the exact specifications. |  |

### Return type

[**BillSingle**](BillSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

