# FireflyIIIClient::BudgetsApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_budget**](BudgetsApi.md#delete_budget) | **DELETE** /api/v1/budgets/{id} | Delete a budget. |
| [**delete_budget_limit**](BudgetsApi.md#delete_budget_limit) | **DELETE** /api/v1/budgets/limits/{id} | Delete a budget limit. |
| [**get_budget**](BudgetsApi.md#get_budget) | **GET** /api/v1/budgets/{id} | Get a single budget. |
| [**get_budget_limit**](BudgetsApi.md#get_budget_limit) | **GET** /api/v1/budgets/limits/{id} | Get single budget limit. |
| [**list_budget**](BudgetsApi.md#list_budget) | **GET** /api/v1/budgets | List all budgets. |
| [**list_budget_limit_by_budget**](BudgetsApi.md#list_budget_limit_by_budget) | **GET** /api/v1/budgets/{id}/limits | Get all limits |
| [**list_transaction_by_budget**](BudgetsApi.md#list_transaction_by_budget) | **GET** /api/v1/budgets/{id}/transactions | All transactions to a budget. |
| [**list_transaction_by_budget_limit**](BudgetsApi.md#list_transaction_by_budget_limit) | **GET** /api/v1/budgets/limits/{id}/transactions | List all transactions by a budget limit ID. |
| [**store_budget**](BudgetsApi.md#store_budget) | **POST** /api/v1/budgets | Store a new budget |
| [**store_budget_limit**](BudgetsApi.md#store_budget_limit) | **POST** /api/v1/budgets/{id}/limits | Store new budget limit. |
| [**update_budget**](BudgetsApi.md#update_budget) | **PUT** /api/v1/budgets/{id} | Update existing budget. |
| [**update_budget_limit**](BudgetsApi.md#update_budget_limit) | **PUT** /api/v1/budgets/limits/{id} | Update existing budget limit. |


## delete_budget

> delete_budget(id)

Delete a budget.

Delete a budget. Transactions will not be deleted.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
id = 1 # Integer | The ID of the budget.

begin
  # Delete a budget.
  api_instance.delete_budget(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->delete_budget: #{e}"
end
```

#### Using the delete_budget_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_budget_with_http_info(id)

```ruby

begin
  # Delete a budget.
  data, status_code, headers = api_instance.delete_budget_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->delete_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the budget. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## delete_budget_limit

> delete_budget_limit(id)

Delete a budget limit.

Delete a budget limit.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
id = 1 # Integer | The ID of the requested budget limit.

begin
  # Delete a budget limit.
  api_instance.delete_budget_limit(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->delete_budget_limit: #{e}"
end
```

#### Using the delete_budget_limit_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_budget_limit_with_http_info(id)

```ruby

begin
  # Delete a budget limit.
  data, status_code, headers = api_instance.delete_budget_limit_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->delete_budget_limit_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the requested budget limit. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_budget

> <BudgetSingle> get_budget(id, opts)

Get a single budget.

Get a single budget. If the start date and end date are submitted as well, the \"spent\" array will be updated accordingly.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
id = 1 # Integer | The ID of the requested budget.
opts = {
  start_date: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to get info on how much the user has spent. 
  end_date: Date.parse('Mon Dec 31 00:00:00 GMT 2018') # Date | A date formatted YYYY-MM-DD, to get info on how much the user has spent. 
}

begin
  # Get a single budget.
  result = api_instance.get_budget(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->get_budget: #{e}"
end
```

#### Using the get_budget_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BudgetSingle>, Integer, Hash)> get_budget_with_http_info(id, opts)

```ruby

begin
  # Get a single budget.
  data, status_code, headers = api_instance.get_budget_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BudgetSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->get_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the requested budget. |  |
| **start_date** | **Date** | A date formatted YYYY-MM-DD, to get info on how much the user has spent.  | [optional] |
| **end_date** | **Date** | A date formatted YYYY-MM-DD, to get info on how much the user has spent.  | [optional] |

### Return type

[**BudgetSingle**](BudgetSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_budget_limit

> <BudgetLimitSingle> get_budget_limit(id)

Get single budget limit.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
id = 1 # Integer | The ID of the requested budget limit.

begin
  # Get single budget limit.
  result = api_instance.get_budget_limit(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->get_budget_limit: #{e}"
end
```

#### Using the get_budget_limit_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BudgetLimitSingle>, Integer, Hash)> get_budget_limit_with_http_info(id)

```ruby

begin
  # Get single budget limit.
  data, status_code, headers = api_instance.get_budget_limit_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BudgetLimitSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->get_budget_limit_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the requested budget limit. |  |

### Return type

[**BudgetLimitSingle**](BudgetLimitSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_budget

> <BudgetArray> list_budget(opts)

List all budgets.

List all the budgets the user has made. If the start date and end date are submitted as well, the \"spent\" array will be updated accordingly.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
opts = {
  page: 1, # Integer | Page number. The default pagination is 50.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to get info on how much the user has spent. You must submit both start and end. 
  _end: Date.parse('Mon Dec 31 00:00:00 GMT 2018') # Date | A date formatted YYYY-MM-DD, to get info on how much the user has spent. You must submit both start and end. 
}

begin
  # List all budgets.
  result = api_instance.list_budget(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->list_budget: #{e}"
end
```

#### Using the list_budget_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BudgetArray>, Integer, Hash)> list_budget_with_http_info(opts)

```ruby

begin
  # List all budgets.
  data, status_code, headers = api_instance.list_budget_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BudgetArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->list_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD, to get info on how much the user has spent. You must submit both start and end.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD, to get info on how much the user has spent. You must submit both start and end.  | [optional] |

### Return type

[**BudgetArray**](BudgetArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_budget_limit_by_budget

> <BudgetLimitArray> list_budget_limit_by_budget(id, opts)

Get all limits

Get all budget limits for this budget and the money spent, and money left. You can limit the list by submitting a date range as well. The \"spent\" array for each budget limit is NOT influenced by the start and end date of your query, but by the start and end date of the budget limit itself. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
id = 1 # Integer | The ID of the requested budget.
opts = {
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. 
  _end: Date.parse('Mon Dec 31 00:00:00 GMT 2018') # Date | A date formatted YYYY-MM-DD. 
}

begin
  # Get all limits
  result = api_instance.list_budget_limit_by_budget(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->list_budget_limit_by_budget: #{e}"
end
```

#### Using the list_budget_limit_by_budget_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BudgetLimitArray>, Integer, Hash)> list_budget_limit_by_budget_with_http_info(id, opts)

```ruby

begin
  # Get all limits
  data, status_code, headers = api_instance.list_budget_limit_by_budget_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BudgetLimitArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->list_budget_limit_by_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the requested budget. |  |
| **start** | **Date** | A date formatted YYYY-MM-DD.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD.  | [optional] |

### Return type

[**BudgetLimitArray**](BudgetLimitArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction_by_budget

> <TransactionArray> list_transaction_by_budget(id, opts)

All transactions to a budget.

Get all transactions linked to a budget, possibly limited by start and end

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
id = 1 # Integer | The ID of the budget.
opts = {
  limit: 5, # Integer | Limits the number of results on one page.
  page: 1, # Integer | Page number. The default pagination is 50.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. 
  _end: Date.parse('Mon Dec 31 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. 
  type: FireflyIIIClient::TransactionTypeFilter::ALL # TransactionTypeFilter | Optional filter on the transaction type(s) returned
}

begin
  # All transactions to a budget.
  result = api_instance.list_transaction_by_budget(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->list_transaction_by_budget: #{e}"
end
```

#### Using the list_transaction_by_budget_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> list_transaction_by_budget_with_http_info(id, opts)

```ruby

begin
  # All transactions to a budget.
  data, status_code, headers = api_instance.list_transaction_by_budget_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->list_transaction_by_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the budget. |  |
| **limit** | **Integer** | Limits the number of results on one page. | [optional] |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD.  | [optional] |
| **type** | [**TransactionTypeFilter**](.md) | Optional filter on the transaction type(s) returned | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction_by_budget_limit

> <TransactionArray> list_transaction_by_budget_limit(id, opts)

List all transactions by a budget limit ID.

List all the transactions within one budget limit. The start and end date are dictated by the budget limit.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
id = 1 # Integer | The ID of the requested budget limit.
opts = {
  page: 1, # Integer | Page number. The default pagination is 50.
  type: FireflyIIIClient::TransactionTypeFilter::ALL # TransactionTypeFilter | Optional filter on the transaction type(s) returned
}

begin
  # List all transactions by a budget limit ID.
  result = api_instance.list_transaction_by_budget_limit(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->list_transaction_by_budget_limit: #{e}"
end
```

#### Using the list_transaction_by_budget_limit_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> list_transaction_by_budget_limit_with_http_info(id, opts)

```ruby

begin
  # List all transactions by a budget limit ID.
  data, status_code, headers = api_instance.list_transaction_by_budget_limit_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->list_transaction_by_budget_limit_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the requested budget limit. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **type** | [**TransactionTypeFilter**](.md) | Optional filter on the transaction type(s) returned | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_budget

> <BudgetSingle> store_budget(budget)

Store a new budget

Creates a new budget. The data required can be submitted as a JSON body or as a list of parameters.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
budget = FireflyIIIClient::Budget.new({ name: 'Bills' }) # Budget | JSON array or key=value pairs with the necessary budget information. See the model for the exact specifications.

begin
  # Store a new budget
  result = api_instance.store_budget(budget)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->store_budget: #{e}"
end
```

#### Using the store_budget_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BudgetSingle>, Integer, Hash)> store_budget_with_http_info(budget)

```ruby

begin
  # Store a new budget
  data, status_code, headers = api_instance.store_budget_with_http_info(budget)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BudgetSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->store_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **budget** | [**Budget**](Budget.md) | JSON array or key&#x3D;value pairs with the necessary budget information. See the model for the exact specifications. |  |

### Return type

[**BudgetSingle**](BudgetSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## store_budget_limit

> <BudgetLimitSingle> store_budget_limit(id, budget_limit)

Store new budget limit.

Store a new budget limit.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
id = 1 # Integer | The ID of the budget.
budget_limit = FireflyIIIClient::BudgetLimit.new({ budget_id: 23, start: Date.parse('Sun Sep 17 00:00:00 GMT 2017'), _end: Date.parse('Sun Sep 17 00:00:00 GMT 2017'), amount: 250 }) # BudgetLimit | JSON array or key=value pairs with the necessary budget information. See the model for the exact specifications.

begin
  # Store new budget limit.
  result = api_instance.store_budget_limit(id, budget_limit)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->store_budget_limit: #{e}"
end
```

#### Using the store_budget_limit_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BudgetLimitSingle>, Integer, Hash)> store_budget_limit_with_http_info(id, budget_limit)

```ruby

begin
  # Store new budget limit.
  data, status_code, headers = api_instance.store_budget_limit_with_http_info(id, budget_limit)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BudgetLimitSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->store_budget_limit_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the budget. |  |
| **budget_limit** | [**BudgetLimit**](BudgetLimit.md) | JSON array or key&#x3D;value pairs with the necessary budget information. See the model for the exact specifications. |  |

### Return type

[**BudgetLimitSingle**](BudgetLimitSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_budget

> <BudgetSingle> update_budget(id, budget)

Update existing budget.

Update existing budget. This endpoint cannot be used to set budget amount limits.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
id = 1 # Integer | The ID of the budget.
budget = FireflyIIIClient::Budget.new({ name: 'Bills' }) # Budget | JSON array with updated budget information. See the model for the exact specifications.

begin
  # Update existing budget.
  result = api_instance.update_budget(id, budget)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->update_budget: #{e}"
end
```

#### Using the update_budget_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BudgetSingle>, Integer, Hash)> update_budget_with_http_info(id, budget)

```ruby

begin
  # Update existing budget.
  data, status_code, headers = api_instance.update_budget_with_http_info(id, budget)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BudgetSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->update_budget_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the budget. |  |
| **budget** | [**Budget**](Budget.md) | JSON array with updated budget information. See the model for the exact specifications. |  |

### Return type

[**BudgetSingle**](BudgetSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_budget_limit

> <BudgetLimitSingle> update_budget_limit(id, budget_limit)

Update existing budget limit.

Update existing budget limit.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::BudgetsApi.new
id = 1 # Integer | The ID of the requested budget limit. The budget limit MUST be associated to the budget ID.
budget_limit = FireflyIIIClient::BudgetLimit.new({ budget_id: 23, start: Date.parse('Sun Sep 17 00:00:00 GMT 2017'), _end: Date.parse('Sun Sep 17 00:00:00 GMT 2017'), amount: 250 }) # BudgetLimit | JSON array with updated budget limit information. See the model for the exact specifications.

begin
  # Update existing budget limit.
  result = api_instance.update_budget_limit(id, budget_limit)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->update_budget_limit: #{e}"
end
```

#### Using the update_budget_limit_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BudgetLimitSingle>, Integer, Hash)> update_budget_limit_with_http_info(id, budget_limit)

```ruby

begin
  # Update existing budget limit.
  data, status_code, headers = api_instance.update_budget_limit_with_http_info(id, budget_limit)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BudgetLimitSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling BudgetsApi->update_budget_limit_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the requested budget limit. The budget limit MUST be associated to the budget ID. |  |
| **budget_limit** | [**BudgetLimit**](BudgetLimit.md) | JSON array with updated budget limit information. See the model for the exact specifications. |  |

### Return type

[**BudgetLimitSingle**](BudgetLimitSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

