# FireflyIIIClient::CategoriesApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_category**](CategoriesApi.md#delete_category) | **DELETE** /api/v1/categories/{id} | Delete a category. |
| [**get_category**](CategoriesApi.md#get_category) | **GET** /api/v1/categories/{id} | Get a single category. |
| [**list_category**](CategoriesApi.md#list_category) | **GET** /api/v1/categories | List all categories. |
| [**list_transaction_by_category**](CategoriesApi.md#list_transaction_by_category) | **GET** /api/v1/categories/{id}/transactions | List all transactions in a category. |
| [**store_category**](CategoriesApi.md#store_category) | **POST** /api/v1/categories | Store a new category |
| [**update_category**](CategoriesApi.md#update_category) | **PUT** /api/v1/categories/{id} | Update existing category. |


## delete_category

> delete_category(id)

Delete a category.

Delete a category. Transactions will not be removed.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CategoriesApi.new
id = 1 # Integer | The ID of the category.

begin
  # Delete a category.
  api_instance.delete_category(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->delete_category: #{e}"
end
```

#### Using the delete_category_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_category_with_http_info(id)

```ruby

begin
  # Delete a category.
  data, status_code, headers = api_instance.delete_category_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->delete_category_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the category. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_category

> <CategorySingle> get_category(id)

Get a single category.

Get a single category.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CategoriesApi.new
id = 1 # Integer | The ID of the category.

begin
  # Get a single category.
  result = api_instance.get_category(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->get_category: #{e}"
end
```

#### Using the get_category_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CategorySingle>, Integer, Hash)> get_category_with_http_info(id)

```ruby

begin
  # Get a single category.
  data, status_code, headers = api_instance.get_category_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CategorySingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->get_category_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the category. |  |

### Return type

[**CategorySingle**](CategorySingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_category

> <CategoryArray> list_category(opts)

List all categories.

List all categories.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CategoriesApi.new
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # List all categories.
  result = api_instance.list_category(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->list_category: #{e}"
end
```

#### Using the list_category_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CategoryArray>, Integer, Hash)> list_category_with_http_info(opts)

```ruby

begin
  # List all categories.
  data, status_code, headers = api_instance.list_category_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CategoryArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->list_category_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**CategoryArray**](CategoryArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction_by_category

> <TransactionArray> list_transaction_by_category(id, opts)

List all transactions in a category.

List all transactions in a category, optionally limited to the date ranges specified.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CategoriesApi.new
id = 1 # Integer | The ID of the category.
opts = {
  page: 1, # Integer | Page number. The default pagination is per 50.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the result list. 
  _end: Date.parse('Mon Dec 31 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the result list. 
  type: FireflyIIIClient::TransactionTypeFilter::ALL # TransactionTypeFilter | Optional filter on the transaction type(s) returned
}

begin
  # List all transactions in a category.
  result = api_instance.list_transaction_by_category(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->list_transaction_by_category: #{e}"
end
```

#### Using the list_transaction_by_category_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> list_transaction_by_category_with_http_info(id, opts)

```ruby

begin
  # List all transactions in a category.
  data, status_code, headers = api_instance.list_transaction_by_category_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->list_transaction_by_category_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the category. |  |
| **page** | **Integer** | Page number. The default pagination is per 50. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD, to limit the result list.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD, to limit the result list.  | [optional] |
| **type** | [**TransactionTypeFilter**](.md) | Optional filter on the transaction type(s) returned | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_category

> <CategorySingle> store_category(category)

Store a new category

Creates a new category. The data required can be submitted as a JSON body or as a list of parameters.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CategoriesApi.new
category = FireflyIIIClient::Category.new({ name: 'Lunch' }) # Category | JSON array or key=value pairs with the necessary category information. See the model for the exact specifications.

begin
  # Store a new category
  result = api_instance.store_category(category)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->store_category: #{e}"
end
```

#### Using the store_category_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CategorySingle>, Integer, Hash)> store_category_with_http_info(category)

```ruby

begin
  # Store a new category
  data, status_code, headers = api_instance.store_category_with_http_info(category)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CategorySingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->store_category_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **category** | [**Category**](Category.md) | JSON array or key&#x3D;value pairs with the necessary category information. See the model for the exact specifications. |  |

### Return type

[**CategorySingle**](CategorySingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_category

> <CategorySingle> update_category(id, category)

Update existing category.

Update existing category.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CategoriesApi.new
id = 1 # Integer | The ID of the category.
category = FireflyIIIClient::Category.new({ name: 'Lunch' }) # Category | JSON array with updated category information. See the model for the exact specifications.

begin
  # Update existing category.
  result = api_instance.update_category(id, category)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->update_category: #{e}"
end
```

#### Using the update_category_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CategorySingle>, Integer, Hash)> update_category_with_http_info(id, category)

```ruby

begin
  # Update existing category.
  data, status_code, headers = api_instance.update_category_with_http_info(id, category)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CategorySingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CategoriesApi->update_category_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the category. |  |
| **category** | [**Category**](Category.md) | JSON array with updated category information. See the model for the exact specifications. |  |

### Return type

[**CategorySingle**](CategorySingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

