# FireflyIIIClient::ChartsApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**get_chart_ab_overview**](ChartsApi.md#get_chart_ab_overview) | **GET** /api/v1/chart/ab/overview/{id} | Dashboard chart with an overview of the available budget. |
| [**get_chart_account_expense**](ChartsApi.md#get_chart_account_expense) | **GET** /api/v1/chart/account/expense | Dashboard chart with expense account balance information. |
| [**get_chart_account_overview**](ChartsApi.md#get_chart_account_overview) | **GET** /api/v1/chart/account/overview | Dashboard chart with asset account balance information. |
| [**get_chart_account_revenue**](ChartsApi.md#get_chart_account_revenue) | **GET** /api/v1/chart/account/revenue | Dashboard chart with revenue account balance information. |
| [**get_chart_category_overview**](ChartsApi.md#get_chart_category_overview) | **GET** /api/v1/chart/category/overview | Dashboard chart with an overview of the users categories. |


## get_chart_ab_overview

> <Array<ChartDataSet>> get_chart_ab_overview(id, start, _end)

Dashboard chart with an overview of the available budget.

This endpoint returns the data required to generate a pie chart for the available budget. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::ChartsApi.new
id = 1 # Integer | The ID of the available budget.
start = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 
_end = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 

begin
  # Dashboard chart with an overview of the available budget.
  result = api_instance.get_chart_ab_overview(id, start, _end)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ChartsApi->get_chart_ab_overview: #{e}"
end
```

#### Using the get_chart_ab_overview_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<ChartDataSet>>, Integer, Hash)> get_chart_ab_overview_with_http_info(id, start, _end)

```ruby

begin
  # Dashboard chart with an overview of the available budget.
  data, status_code, headers = api_instance.get_chart_ab_overview_with_http_info(id, start, _end)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<ChartDataSet>>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ChartsApi->get_chart_ab_overview_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the available budget. |  |
| **start** | **Date** | A date formatted YYYY-MM-DD.  |  |
| **_end** | **Date** | A date formatted YYYY-MM-DD.  |  |

### Return type

[**Array&lt;ChartDataSet&gt;**](ChartDataSet.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_chart_account_expense

> <Array<ChartDataSet>> get_chart_account_expense(start, _end)

Dashboard chart with expense account balance information.

This endpoint returns the data required to generate a chart that shows the user how much they've spent on their expense accounts. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::ChartsApi.new
start = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 
_end = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 

begin
  # Dashboard chart with expense account balance information.
  result = api_instance.get_chart_account_expense(start, _end)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ChartsApi->get_chart_account_expense: #{e}"
end
```

#### Using the get_chart_account_expense_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<ChartDataSet>>, Integer, Hash)> get_chart_account_expense_with_http_info(start, _end)

```ruby

begin
  # Dashboard chart with expense account balance information.
  data, status_code, headers = api_instance.get_chart_account_expense_with_http_info(start, _end)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<ChartDataSet>>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ChartsApi->get_chart_account_expense_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **start** | **Date** | A date formatted YYYY-MM-DD.  |  |
| **_end** | **Date** | A date formatted YYYY-MM-DD.  |  |

### Return type

[**Array&lt;ChartDataSet&gt;**](ChartDataSet.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_chart_account_overview

> <Array<ChartDataSet>> get_chart_account_overview(start, _end)

Dashboard chart with asset account balance information.

This endpoint returns the data required to generate a chart with basic asset account balance information. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::ChartsApi.new
start = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 
_end = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 

begin
  # Dashboard chart with asset account balance information.
  result = api_instance.get_chart_account_overview(start, _end)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ChartsApi->get_chart_account_overview: #{e}"
end
```

#### Using the get_chart_account_overview_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<ChartDataSet>>, Integer, Hash)> get_chart_account_overview_with_http_info(start, _end)

```ruby

begin
  # Dashboard chart with asset account balance information.
  data, status_code, headers = api_instance.get_chart_account_overview_with_http_info(start, _end)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<ChartDataSet>>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ChartsApi->get_chart_account_overview_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **start** | **Date** | A date formatted YYYY-MM-DD.  |  |
| **_end** | **Date** | A date formatted YYYY-MM-DD.  |  |

### Return type

[**Array&lt;ChartDataSet&gt;**](ChartDataSet.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_chart_account_revenue

> <Array<ChartDataSet>> get_chart_account_revenue(start, _end)

Dashboard chart with revenue account balance information.

This endpoint returns the data required to generate a chart that shows the user how much they've earned from their revenue accounts. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::ChartsApi.new
start = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 
_end = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 

begin
  # Dashboard chart with revenue account balance information.
  result = api_instance.get_chart_account_revenue(start, _end)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ChartsApi->get_chart_account_revenue: #{e}"
end
```

#### Using the get_chart_account_revenue_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<ChartDataSet>>, Integer, Hash)> get_chart_account_revenue_with_http_info(start, _end)

```ruby

begin
  # Dashboard chart with revenue account balance information.
  data, status_code, headers = api_instance.get_chart_account_revenue_with_http_info(start, _end)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<ChartDataSet>>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ChartsApi->get_chart_account_revenue_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **start** | **Date** | A date formatted YYYY-MM-DD.  |  |
| **_end** | **Date** | A date formatted YYYY-MM-DD.  |  |

### Return type

[**Array&lt;ChartDataSet&gt;**](ChartDataSet.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_chart_category_overview

> <Array<ChartDataSet>> get_chart_category_overview(start, _end)

Dashboard chart with an overview of the users categories.

This endpoint returns the data required to generate a bar chart for the expenses and incomes on the users categories. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::ChartsApi.new
start = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 
_end = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 

begin
  # Dashboard chart with an overview of the users categories.
  result = api_instance.get_chart_category_overview(start, _end)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ChartsApi->get_chart_category_overview: #{e}"
end
```

#### Using the get_chart_category_overview_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<ChartDataSet>>, Integer, Hash)> get_chart_category_overview_with_http_info(start, _end)

```ruby

begin
  # Dashboard chart with an overview of the users categories.
  data, status_code, headers = api_instance.get_chart_category_overview_with_http_info(start, _end)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<ChartDataSet>>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ChartsApi->get_chart_category_overview_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **start** | **Date** | A date formatted YYYY-MM-DD.  |  |
| **_end** | **Date** | A date formatted YYYY-MM-DD.  |  |

### Return type

[**Array&lt;ChartDataSet&gt;**](ChartDataSet.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

