# FireflyIIIClient::ConfigurationApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**get_configuration**](ConfigurationApi.md#get_configuration) | **GET** /api/v1/configuration | Get Firefly III system configuration. |
| [**set_configuration**](ConfigurationApi.md#set_configuration) | **POST** /api/v1/configuration/{name} | Update configuration |


## get_configuration

> <SystemConfiguration> get_configuration

Get Firefly III system configuration.

Get system configuration

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::ConfigurationApi.new

begin
  # Get Firefly III system configuration.
  result = api_instance.get_configuration
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ConfigurationApi->get_configuration: #{e}"
end
```

#### Using the get_configuration_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<SystemConfiguration>, Integer, Hash)> get_configuration_with_http_info

```ruby

begin
  # Get Firefly III system configuration.
  data, status_code, headers = api_instance.get_configuration_with_http_info
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <SystemConfiguration>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ConfigurationApi->get_configuration_with_http_info: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

[**SystemConfiguration**](SystemConfiguration.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## set_configuration

> <SystemConfiguration> set_configuration(name, value)

Update configuration

Set a single config value.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::ConfigurationApi.new
name = 'is_demo_site' # String | The configuration value name.
value = 'value_example' # String | Can be a number or a boolean. This depends on the actual configuration value.

begin
  # Update configuration
  result = api_instance.set_configuration(name, value)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ConfigurationApi->set_configuration: #{e}"
end
```

#### Using the set_configuration_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<SystemConfiguration>, Integer, Hash)> set_configuration_with_http_info(name, value)

```ruby

begin
  # Update configuration
  data, status_code, headers = api_instance.set_configuration_with_http_info(name, value)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <SystemConfiguration>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ConfigurationApi->set_configuration_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **name** | **String** | The configuration value name. |  |
| **value** | **String** | Can be a number or a boolean. This depends on the actual configuration value. |  |

### Return type

[**SystemConfiguration**](SystemConfiguration.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/x-www-form-urlencoded, application/json
- **Accept**: application/json

