# FireflyIIIClient::CurrenciesApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**default_currency**](CurrenciesApi.md#default_currency) | **POST** /api/v1/currencies/{code}/default | Make currency default currency. |
| [**delete_currency**](CurrenciesApi.md#delete_currency) | **DELETE** /api/v1/currencies/{code} | Delete a currency. |
| [**disable_currency**](CurrenciesApi.md#disable_currency) | **POST** /api/v1/currencies/{code}/disable | Disable a currency. |
| [**enable_currency**](CurrenciesApi.md#enable_currency) | **POST** /api/v1/currencies/{code}/enable | Enable a single currency. |
| [**get_currency**](CurrenciesApi.md#get_currency) | **GET** /api/v1/currencies/{code} | Get a single currency. |
| [**list_account_by_currency**](CurrenciesApi.md#list_account_by_currency) | **GET** /api/v1/currencies/{code}/accounts | List all accounts with this currency. |
| [**list_available_budget_by_currency**](CurrenciesApi.md#list_available_budget_by_currency) | **GET** /api/v1/currencies/{code}/available_budgets | List all available budgets with this currency. |
| [**list_bill_by_currency**](CurrenciesApi.md#list_bill_by_currency) | **GET** /api/v1/currencies/{code}/bills | List all bills with this currency. |
| [**list_budget_limit_by_currency**](CurrenciesApi.md#list_budget_limit_by_currency) | **GET** /api/v1/currencies/{code}/budget_limits | List all budget limits with this currency |
| [**list_currency**](CurrenciesApi.md#list_currency) | **GET** /api/v1/currencies | List all currencies. |
| [**list_exchange_rate_by_currency**](CurrenciesApi.md#list_exchange_rate_by_currency) | **GET** /api/v1/currencies/{code}/cer | List all known exchange rates with (from or to) this currency. |
| [**list_recurrence_by_currency**](CurrenciesApi.md#list_recurrence_by_currency) | **GET** /api/v1/currencies/{code}/recurrences | List all recurring transactions with this currency. |
| [**list_rule_by_currency**](CurrenciesApi.md#list_rule_by_currency) | **GET** /api/v1/currencies/{code}/rules | List all rules with this currency. |
| [**list_transaction_by_currency**](CurrenciesApi.md#list_transaction_by_currency) | **GET** /api/v1/currencies/{code}/transactions | List all transactions with this currency. |
| [**store_currency**](CurrenciesApi.md#store_currency) | **POST** /api/v1/currencies | Store a new currency |
| [**update_currency**](CurrenciesApi.md#update_currency) | **PUT** /api/v1/currencies/{code} | Update existing currency. |


## default_currency

> <CurrencySingle> default_currency(code)

Make currency default currency.

Make this currency the default currency. If the currency is not enabled, it will be enabled as well.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'USD' # String | The currency code.

begin
  # Make currency default currency.
  result = api_instance.default_currency(code)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->default_currency: #{e}"
end
```

#### Using the default_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CurrencySingle>, Integer, Hash)> default_currency_with_http_info(code)

```ruby

begin
  # Make currency default currency.
  data, status_code, headers = api_instance.default_currency_with_http_info(code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CurrencySingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->default_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |

### Return type

[**CurrencySingle**](CurrencySingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## delete_currency

> delete_currency(code)

Delete a currency.

Delete a currency.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'GBP' # String | The currency code.

begin
  # Delete a currency.
  api_instance.delete_currency(code)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->delete_currency: #{e}"
end
```

#### Using the delete_currency_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_currency_with_http_info(code)

```ruby

begin
  # Delete a currency.
  data, status_code, headers = api_instance.delete_currency_with_http_info(code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->delete_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## disable_currency

> <CurrencySingle> disable_currency(code)

Disable a currency.

Disable a currency.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 56 # Integer | The currency code.

begin
  # Disable a currency.
  result = api_instance.disable_currency(code)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->disable_currency: #{e}"
end
```

#### Using the disable_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CurrencySingle>, Integer, Hash)> disable_currency_with_http_info(code)

```ruby

begin
  # Disable a currency.
  data, status_code, headers = api_instance.disable_currency_with_http_info(code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CurrencySingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->disable_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **Integer** | The currency code. |  |

### Return type

[**CurrencySingle**](CurrencySingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## enable_currency

> <CurrencySingle> enable_currency(code)

Enable a single currency.

Enable a single currency.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'USD' # String | The currency code.

begin
  # Enable a single currency.
  result = api_instance.enable_currency(code)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->enable_currency: #{e}"
end
```

#### Using the enable_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CurrencySingle>, Integer, Hash)> enable_currency_with_http_info(code)

```ruby

begin
  # Enable a single currency.
  data, status_code, headers = api_instance.enable_currency_with_http_info(code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CurrencySingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->enable_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |

### Return type

[**CurrencySingle**](CurrencySingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_currency

> <CurrencySingle> get_currency(code)

Get a single currency.

Get a single currency.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'USD' # String | The currency code.

begin
  # Get a single currency.
  result = api_instance.get_currency(code)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->get_currency: #{e}"
end
```

#### Using the get_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CurrencySingle>, Integer, Hash)> get_currency_with_http_info(code)

```ruby

begin
  # Get a single currency.
  data, status_code, headers = api_instance.get_currency_with_http_info(code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CurrencySingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->get_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |

### Return type

[**CurrencySingle**](CurrencySingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_account_by_currency

> <AccountArray> list_account_by_currency(code, opts)

List all accounts with this currency.

List all accounts with this currency.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'USD' # String | The currency code.
opts = {
  page: 1, # Integer | Page number. The default pagination is 50.
  date: 'date_example', # String | A date formatted YYYY-MM-DD. When added to the request, Firefly III will show the account's balance on that day. 
  type: FireflyIIIClient::AccountTypeFilter::ALL # AccountTypeFilter | Optional filter on the account type(s) returned
}

begin
  # List all accounts with this currency.
  result = api_instance.list_account_by_currency(code, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_account_by_currency: #{e}"
end
```

#### Using the list_account_by_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AccountArray>, Integer, Hash)> list_account_by_currency_with_http_info(code, opts)

```ruby

begin
  # List all accounts with this currency.
  data, status_code, headers = api_instance.list_account_by_currency_with_http_info(code, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AccountArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_account_by_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **date** | **String** | A date formatted YYYY-MM-DD. When added to the request, Firefly III will show the account&#39;s balance on that day.  | [optional] |
| **type** | [**AccountTypeFilter**](.md) | Optional filter on the account type(s) returned | [optional] |

### Return type

[**AccountArray**](AccountArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_available_budget_by_currency

> <AvailableBudgetArray> list_available_budget_by_currency(code, opts)

List all available budgets with this currency.

List all available budgets with this currency.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'EUR' # String | The currency code.
opts = {
  page: 1 # Integer | Page number. The default pagination is 50
}

begin
  # List all available budgets with this currency.
  result = api_instance.list_available_budget_by_currency(code, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_available_budget_by_currency: #{e}"
end
```

#### Using the list_available_budget_by_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AvailableBudgetArray>, Integer, Hash)> list_available_budget_by_currency_with_http_info(code, opts)

```ruby

begin
  # List all available budgets with this currency.
  data, status_code, headers = api_instance.list_available_budget_by_currency_with_http_info(code, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AvailableBudgetArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_available_budget_by_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |
| **page** | **Integer** | Page number. The default pagination is 50 | [optional] |

### Return type

[**AvailableBudgetArray**](AvailableBudgetArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_bill_by_currency

> <BillArray> list_bill_by_currency(code, opts)

List all bills with this currency.

List all bills with this currency.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'USD' # String | The currency code.
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # List all bills with this currency.
  result = api_instance.list_bill_by_currency(code, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_bill_by_currency: #{e}"
end
```

#### Using the list_bill_by_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BillArray>, Integer, Hash)> list_bill_by_currency_with_http_info(code, opts)

```ruby

begin
  # List all bills with this currency.
  data, status_code, headers = api_instance.list_bill_by_currency_with_http_info(code, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BillArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_bill_by_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**BillArray**](BillArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_budget_limit_by_currency

> <BudgetLimitArray> list_budget_limit_by_currency(code, opts)

List all budget limits with this currency

List all budget limits with this currency

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'USD' # String | The currency code.
opts = {
  page: 1, # Integer | Page number. The default pagination is 50.
  start: Date.parse('Mon Jan 01 00:00:00 GMT 2018'), # Date | Start date for the budget limit list.
  _end: Date.parse('Wed Jan 31 00:00:00 GMT 2018') # Date | End date for the budget limit list.
}

begin
  # List all budget limits with this currency
  result = api_instance.list_budget_limit_by_currency(code, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_budget_limit_by_currency: #{e}"
end
```

#### Using the list_budget_limit_by_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BudgetLimitArray>, Integer, Hash)> list_budget_limit_by_currency_with_http_info(code, opts)

```ruby

begin
  # List all budget limits with this currency
  data, status_code, headers = api_instance.list_budget_limit_by_currency_with_http_info(code, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BudgetLimitArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_budget_limit_by_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **start** | **Date** | Start date for the budget limit list. | [optional] |
| **_end** | **Date** | End date for the budget limit list. | [optional] |

### Return type

[**BudgetLimitArray**](BudgetLimitArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_currency

> <CurrencyArray> list_currency(opts)

List all currencies.

List all currencies.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # List all currencies.
  result = api_instance.list_currency(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_currency: #{e}"
end
```

#### Using the list_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CurrencyArray>, Integer, Hash)> list_currency_with_http_info(opts)

```ruby

begin
  # List all currencies.
  data, status_code, headers = api_instance.list_currency_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CurrencyArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**CurrencyArray**](CurrencyArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_exchange_rate_by_currency

> <ExchangeRateArray> list_exchange_rate_by_currency(code, opts)

List all known exchange rates with (from or to) this currency.

List all known exchange rates.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'GBP' # String | The currency code.
opts = {
  page: 1, # Integer | Page number. The default pagination is 50.
  date: Date.parse('2013-10-20'), # Date | The date of which you want to know the exchange rate 
  start: Date.parse('2013-10-20'), # Date | Use this instead of the date parameter to search for a range of currency exchange values. 
  _end: Date.parse('2013-10-20') # Date | Use this instead of the date parameter to search for a range of currency exchange values. 
}

begin
  # List all known exchange rates with (from or to) this currency.
  result = api_instance.list_exchange_rate_by_currency(code, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_exchange_rate_by_currency: #{e}"
end
```

#### Using the list_exchange_rate_by_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ExchangeRateArray>, Integer, Hash)> list_exchange_rate_by_currency_with_http_info(code, opts)

```ruby

begin
  # List all known exchange rates with (from or to) this currency.
  data, status_code, headers = api_instance.list_exchange_rate_by_currency_with_http_info(code, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ExchangeRateArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_exchange_rate_by_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **date** | **Date** | The date of which you want to know the exchange rate  | [optional] |
| **start** | **Date** | Use this instead of the date parameter to search for a range of currency exchange values.  | [optional] |
| **_end** | **Date** | Use this instead of the date parameter to search for a range of currency exchange values.  | [optional] |

### Return type

[**ExchangeRateArray**](ExchangeRateArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_recurrence_by_currency

> <RecurrenceArray> list_recurrence_by_currency(code, opts)

List all recurring transactions with this currency.

List all recurring transactions with this currency.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'EUR' # String | The currency code.
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # List all recurring transactions with this currency.
  result = api_instance.list_recurrence_by_currency(code, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_recurrence_by_currency: #{e}"
end
```

#### Using the list_recurrence_by_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RecurrenceArray>, Integer, Hash)> list_recurrence_by_currency_with_http_info(code, opts)

```ruby

begin
  # List all recurring transactions with this currency.
  data, status_code, headers = api_instance.list_recurrence_by_currency_with_http_info(code, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RecurrenceArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_recurrence_by_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**RecurrenceArray**](RecurrenceArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_rule_by_currency

> <RuleArray> list_rule_by_currency(code, opts)

List all rules with this currency.

List all rules with this currency.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'USD' # String | The currency code.
opts = {
  page: 1 # Integer | Page number. The default pagination per 50.
}

begin
  # List all rules with this currency.
  result = api_instance.list_rule_by_currency(code, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_rule_by_currency: #{e}"
end
```

#### Using the list_rule_by_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RuleArray>, Integer, Hash)> list_rule_by_currency_with_http_info(code, opts)

```ruby

begin
  # List all rules with this currency.
  data, status_code, headers = api_instance.list_rule_by_currency_with_http_info(code, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RuleArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_rule_by_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |
| **page** | **Integer** | Page number. The default pagination per 50. | [optional] |

### Return type

[**RuleArray**](RuleArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction_by_currency

> <TransactionArray> list_transaction_by_currency(code, opts)

List all transactions with this currency.

List all transactions with this currency.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'USD' # String | The currency code.
opts = {
  page: 1, # Integer | Page number. The default pagination is per 50.
  start_date: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the list of transactions. 
  end_date: Date.parse('Mon Dec 31 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the list of transactions. 
  type: FireflyIIIClient::TransactionTypeFilter::ALL # TransactionTypeFilter | Optional filter on the transaction type(s) returned
}

begin
  # List all transactions with this currency.
  result = api_instance.list_transaction_by_currency(code, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_transaction_by_currency: #{e}"
end
```

#### Using the list_transaction_by_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> list_transaction_by_currency_with_http_info(code, opts)

```ruby

begin
  # List all transactions with this currency.
  data, status_code, headers = api_instance.list_transaction_by_currency_with_http_info(code, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->list_transaction_by_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |
| **page** | **Integer** | Page number. The default pagination is per 50. | [optional] |
| **start_date** | **Date** | A date formatted YYYY-MM-DD, to limit the list of transactions.  | [optional] |
| **end_date** | **Date** | A date formatted YYYY-MM-DD, to limit the list of transactions.  | [optional] |
| **type** | [**TransactionTypeFilter**](.md) | Optional filter on the transaction type(s) returned | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_currency

> <CurrencySingle> store_currency(currency)

Store a new currency

Creates a new currency. The data required can be submitted as a JSON body or as a list of parameters.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
currency = FireflyIIIClient::Currency.new({ code: 'AMS', name: 'Ankh-Morpork dollar', symbol: 'AM$' }) # Currency | JSON array or key=value pairs with the necessary currency information. See the model for the exact specifications.

begin
  # Store a new currency
  result = api_instance.store_currency(currency)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->store_currency: #{e}"
end
```

#### Using the store_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CurrencySingle>, Integer, Hash)> store_currency_with_http_info(currency)

```ruby

begin
  # Store a new currency
  data, status_code, headers = api_instance.store_currency_with_http_info(currency)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CurrencySingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->store_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **currency** | [**Currency**](Currency.md) | JSON array or key&#x3D;value pairs with the necessary currency information. See the model for the exact specifications. |  |

### Return type

[**CurrencySingle**](CurrencySingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_currency

> <CurrencySingle> update_currency(code, currency)

Update existing currency.

Update existing currency.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrenciesApi.new
code = 'EUR' # String | The currency code.
currency = FireflyIIIClient::Currency.new({ code: 'AMS', name: 'Ankh-Morpork dollar', symbol: 'AM$' }) # Currency | JSON array with updated currency information. See the model for the exact specifications.

begin
  # Update existing currency.
  result = api_instance.update_currency(code, currency)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->update_currency: #{e}"
end
```

#### Using the update_currency_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CurrencySingle>, Integer, Hash)> update_currency_with_http_info(code, currency)

```ruby

begin
  # Update existing currency.
  data, status_code, headers = api_instance.update_currency_with_http_info(code, currency)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CurrencySingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrenciesApi->update_currency_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **code** | **String** | The currency code. |  |
| **currency** | [**Currency**](Currency.md) | JSON array with updated currency information. See the model for the exact specifications. |  |

### Return type

[**CurrencySingle**](CurrencySingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

