# FireflyIIIClient::CurrencyExchangeRatesApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**get_exchange_rate**](CurrencyExchangeRatesApi.md#get_exchange_rate) | **GET** /api/v1/cer | Get an exchange rate. |


## get_exchange_rate

> <ExchangeRate> get_exchange_rate(opts)

Get an exchange rate.

Get an exchange rate. If Firefly III doesn't know the rate it will set the rate to 1.0.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::CurrencyExchangeRatesApi.new
opts = {
  from: 'EUR', # String | The source currency code. If omitted, defaults to EUR.
  to: 'USD', # String | The destination currency code. If omitted, defaults to USD.
  date: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | The date you want to know the exchange rate on.
  amount: 120.12 # Float | The amount in the source currency. If added, Firefly III will calculate the amount in the destination currency.
}

begin
  # Get an exchange rate.
  result = api_instance.get_exchange_rate(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrencyExchangeRatesApi->get_exchange_rate: #{e}"
end
```

#### Using the get_exchange_rate_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ExchangeRate>, Integer, Hash)> get_exchange_rate_with_http_info(opts)

```ruby

begin
  # Get an exchange rate.
  data, status_code, headers = api_instance.get_exchange_rate_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ExchangeRate>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling CurrencyExchangeRatesApi->get_exchange_rate_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **from** | **String** | The source currency code. If omitted, defaults to EUR. | [optional] |
| **to** | **String** | The destination currency code. If omitted, defaults to USD. | [optional] |
| **date** | **Date** | The date you want to know the exchange rate on. | [optional] |
| **amount** | **Float** | The amount in the source currency. If added, Firefly III will calculate the amount in the destination currency. | [optional] |

### Return type

[**ExchangeRate**](ExchangeRate.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

