# FireflyIIIClient::ImportApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**get_import**](ImportApi.md#get_import) | **GET** /api/v1/import/{key} | Show info on a single import |
| [**list_import**](ImportApi.md#list_import) | **GET** /api/v1/import/list | List al imports |
| [**list_transaction_by_import**](ImportApi.md#list_transaction_by_import) | **GET** /api/v1/import/{key}/transactions | List all transactions related to the import job. The correlation is made through the tag. |


## get_import

> <ImportJobSingle> get_import(key)

Show info on a single import

Show info on single import.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::ImportApi.new
key = 'x2Akaijm2' # String | The job key of an import job.

begin
  # Show info on a single import
  result = api_instance.get_import(key)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ImportApi->get_import: #{e}"
end
```

#### Using the get_import_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ImportJobSingle>, Integer, Hash)> get_import_with_http_info(key)

```ruby

begin
  # Show info on a single import
  data, status_code, headers = api_instance.get_import_with_http_info(key)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ImportJobSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ImportApi->get_import_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **key** | **String** | The job key of an import job. |  |

### Return type

[**ImportJobSingle**](ImportJobSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_import

> <ImportJobArray> list_import(opts)

List al imports

List all imports

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::ImportApi.new
opts = {
  page: 1 # Integer | Page number. The default pagination is per 50 items.
}

begin
  # List al imports
  result = api_instance.list_import(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ImportApi->list_import: #{e}"
end
```

#### Using the list_import_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ImportJobArray>, Integer, Hash)> list_import_with_http_info(opts)

```ruby

begin
  # List al imports
  data, status_code, headers = api_instance.list_import_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ImportJobArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ImportApi->list_import_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is per 50 items. | [optional] |

### Return type

[**ImportJobArray**](ImportJobArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction_by_import

> <TransactionArray> list_transaction_by_import(key, opts)

List all transactions related to the import job. The correlation is made through the tag.

See summary 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::ImportApi.new
key = 'abcde' # String | The key of the import job
opts = {
  page: 1, # Integer | Page number. The default pagination is 50.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. This is the start date of the selected range (inclusive). 
  _end: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. This is the end date of the selected range (inclusive). 
  type: FireflyIIIClient::TransactionTypeFilter::ALL # TransactionTypeFilter | Optional filter on the transaction type(s) returned.
}

begin
  # List all transactions related to the import job. The correlation is made through the tag.
  result = api_instance.list_transaction_by_import(key, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ImportApi->list_transaction_by_import: #{e}"
end
```

#### Using the list_transaction_by_import_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> list_transaction_by_import_with_http_info(key, opts)

```ruby

begin
  # List all transactions related to the import job. The correlation is made through the tag.
  data, status_code, headers = api_instance.list_transaction_by_import_with_http_info(key, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling ImportApi->list_transaction_by_import_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **key** | **String** | The key of the import job |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD. This is the start date of the selected range (inclusive).  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD. This is the end date of the selected range (inclusive).  | [optional] |
| **type** | [**TransactionTypeFilter**](.md) | Optional filter on the transaction type(s) returned. | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

