# FireflyIIIClient::LinksApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_link_type**](LinksApi.md#delete_link_type) | **DELETE** /api/v1/link_types/{id} | Permanently delete link type. |
| [**delete_transaction_link**](LinksApi.md#delete_transaction_link) | **DELETE** /api/v1/transaction_links/{id} | Permanently delete link between transactions. |
| [**get_link_type**](LinksApi.md#get_link_type) | **GET** /api/v1/link_types/{id} | Get single a link type. |
| [**get_transaction_link**](LinksApi.md#get_transaction_link) | **GET** /api/v1/transaction_links/{id} | Get a single link. |
| [**list_link_type**](LinksApi.md#list_link_type) | **GET** /api/v1/link_types | List all types of links. |
| [**list_transaction_by_link_type**](LinksApi.md#list_transaction_by_link_type) | **GET** /api/v1/link_types/{id}/transactions | List all transactions under this link type. |
| [**list_transaction_link**](LinksApi.md#list_transaction_link) | **GET** /api/v1/transaction_links | List all transaction links. |
| [**store_link_type**](LinksApi.md#store_link_type) | **POST** /api/v1/link_types | Create a new link type |
| [**store_transaction_link**](LinksApi.md#store_transaction_link) | **POST** /api/v1/transaction_links | Create a new link between transactions |
| [**update_link_type**](LinksApi.md#update_link_type) | **PUT** /api/v1/link_types/{id} | Update existing link type. |
| [**update_transaction_link**](LinksApi.md#update_transaction_link) | **PUT** /api/v1/transaction_links/{id} | Update an existing link between transactions. |


## delete_link_type

> delete_link_type(id)

Permanently delete link type.

Will permanently delete a link type. The links between transactions will be removed. The transactions themselves remain. You cannot delete some of the system provided link types, indicated by the editable=false flag when you list it. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::LinksApi.new
id = 1 # Integer | The ID of the link type.

begin
  # Permanently delete link type.
  api_instance.delete_link_type(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->delete_link_type: #{e}"
end
```

#### Using the delete_link_type_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_link_type_with_http_info(id)

```ruby

begin
  # Permanently delete link type.
  data, status_code, headers = api_instance.delete_link_type_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->delete_link_type_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the link type. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## delete_transaction_link

> delete_transaction_link(id)

Permanently delete link between transactions.

Will permanently delete link. Transactions remain. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::LinksApi.new
id = 1 # Integer | The ID of the transaction link.

begin
  # Permanently delete link between transactions.
  api_instance.delete_transaction_link(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->delete_transaction_link: #{e}"
end
```

#### Using the delete_transaction_link_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_transaction_link_with_http_info(id)

```ruby

begin
  # Permanently delete link between transactions.
  data, status_code, headers = api_instance.delete_transaction_link_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->delete_transaction_link_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the transaction link. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_link_type

> <LinkTypeSingle> get_link_type(id)

Get single a link type.

Returns a single link type by its ID. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::LinksApi.new
id = 1 # Integer | The ID of the link type.

begin
  # Get single a link type.
  result = api_instance.get_link_type(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->get_link_type: #{e}"
end
```

#### Using the get_link_type_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<LinkTypeSingle>, Integer, Hash)> get_link_type_with_http_info(id)

```ruby

begin
  # Get single a link type.
  data, status_code, headers = api_instance.get_link_type_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <LinkTypeSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->get_link_type_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the link type. |  |

### Return type

[**LinkTypeSingle**](LinkTypeSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_transaction_link

> <TransactionLinkSingle> get_transaction_link(id)

Get a single link.

Returns a single link by its ID. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::LinksApi.new
id = 1 # Integer | The ID of the transaction link.

begin
  # Get a single link.
  result = api_instance.get_transaction_link(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->get_transaction_link: #{e}"
end
```

#### Using the get_transaction_link_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionLinkSingle>, Integer, Hash)> get_transaction_link_with_http_info(id)

```ruby

begin
  # Get a single link.
  data, status_code, headers = api_instance.get_transaction_link_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionLinkSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->get_transaction_link_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the transaction link. |  |

### Return type

[**TransactionLinkSingle**](TransactionLinkSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_link_type

> <LinkTypeArray> list_link_type(opts)

List all types of links.

List all the link types the system has. These include the default ones as well as any new ones. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::LinksApi.new
opts = {
  page: 1 # Integer | Page number. The default pagination is 50 items.
}

begin
  # List all types of links.
  result = api_instance.list_link_type(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->list_link_type: #{e}"
end
```

#### Using the list_link_type_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<LinkTypeArray>, Integer, Hash)> list_link_type_with_http_info(opts)

```ruby

begin
  # List all types of links.
  data, status_code, headers = api_instance.list_link_type_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <LinkTypeArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->list_link_type_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50 items. | [optional] |

### Return type

[**LinkTypeArray**](LinkTypeArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction_by_link_type

> <TransactionArray> list_transaction_by_link_type(id, opts)

List all transactions under this link type.

List all transactions under this link type, both the inward and outward transactions. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::LinksApi.new
id = 1 # Integer | The ID of the link type.
opts = {
  page: 1, # Integer | Page number. The default pagination is per 50 items.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the results. 
  _end: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the results. 
  type: FireflyIIIClient::TransactionTypeFilter::ALL # TransactionTypeFilter | Optional filter on the transaction type(s) returned.
}

begin
  # List all transactions under this link type.
  result = api_instance.list_transaction_by_link_type(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->list_transaction_by_link_type: #{e}"
end
```

#### Using the list_transaction_by_link_type_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> list_transaction_by_link_type_with_http_info(id, opts)

```ruby

begin
  # List all transactions under this link type.
  data, status_code, headers = api_instance.list_transaction_by_link_type_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->list_transaction_by_link_type_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the link type. |  |
| **page** | **Integer** | Page number. The default pagination is per 50 items. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD, to limit the results.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD, to limit the results.  | [optional] |
| **type** | [**TransactionTypeFilter**](.md) | Optional filter on the transaction type(s) returned. | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction_link

> <TransactionLinkArray> list_transaction_link(opts)

List all transaction links.

List all the transaction links. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::LinksApi.new
opts = {
  page: 1 # Integer | Page number. The default pagination is per 50 items.
}

begin
  # List all transaction links.
  result = api_instance.list_transaction_link(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->list_transaction_link: #{e}"
end
```

#### Using the list_transaction_link_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionLinkArray>, Integer, Hash)> list_transaction_link_with_http_info(opts)

```ruby

begin
  # List all transaction links.
  data, status_code, headers = api_instance.list_transaction_link_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionLinkArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->list_transaction_link_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is per 50 items. | [optional] |

### Return type

[**TransactionLinkArray**](TransactionLinkArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_link_type

> <LinkTypeSingle> store_link_type(link_type)

Create a new link type

Creates a new link type. The data required can be submitted as a JSON body or as a list of parameters (in key=value pairs, like a webform).

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::LinksApi.new
link_type = FireflyIIIClient::LinkType.new({ name: 'Paid', inward: 'is (partially) paid for by', outward: '(partially) pays for' }) # LinkType | JSON array with the necessary link type information or key=value pairs. See the model for the exact specifications.

begin
  # Create a new link type
  result = api_instance.store_link_type(link_type)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->store_link_type: #{e}"
end
```

#### Using the store_link_type_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<LinkTypeSingle>, Integer, Hash)> store_link_type_with_http_info(link_type)

```ruby

begin
  # Create a new link type
  data, status_code, headers = api_instance.store_link_type_with_http_info(link_type)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <LinkTypeSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->store_link_type_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **link_type** | [**LinkType**](LinkType.md) | JSON array with the necessary link type information or key&#x3D;value pairs. See the model for the exact specifications. |  |

### Return type

[**LinkTypeSingle**](LinkTypeSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## store_transaction_link

> <TransactionLinkSingle> store_transaction_link(transaction_link)

Create a new link between transactions

Store a new link between two transactions. For this end point you need the journal_id from a transaction.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::LinksApi.new
transaction_link = FireflyIIIClient::TransactionLink.new({ link_type_id: 5, inward_id: 131, outward_id: 131 }) # TransactionLink | JSON array with the necessary link type information or key=value pairs. See the model for the exact specifications.

begin
  # Create a new link between transactions
  result = api_instance.store_transaction_link(transaction_link)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->store_transaction_link: #{e}"
end
```

#### Using the store_transaction_link_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionLinkSingle>, Integer, Hash)> store_transaction_link_with_http_info(transaction_link)

```ruby

begin
  # Create a new link between transactions
  data, status_code, headers = api_instance.store_transaction_link_with_http_info(transaction_link)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionLinkSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->store_transaction_link_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **transaction_link** | [**TransactionLink**](TransactionLink.md) | JSON array with the necessary link type information or key&#x3D;value pairs. See the model for the exact specifications. |  |

### Return type

[**TransactionLinkSingle**](TransactionLinkSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_link_type

> <LinkTypeSingle> update_link_type(id, link_type)

Update existing link type.

Used to update a single link type. All fields that are not submitted will be cleared (set to NULL). The model will tell you which fields are mandatory. You cannot update some of the system provided link types, indicated by the editable=false flag when you list it. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::LinksApi.new
id = 1 # Integer | The ID of the link type.
link_type = FireflyIIIClient::LinkType.new({ name: 'Paid', inward: 'is (partially) paid for by', outward: '(partially) pays for' }) # LinkType | JSON array or formdata with updated link type information. See the model for the exact specifications.

begin
  # Update existing link type.
  result = api_instance.update_link_type(id, link_type)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->update_link_type: #{e}"
end
```

#### Using the update_link_type_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<LinkTypeSingle>, Integer, Hash)> update_link_type_with_http_info(id, link_type)

```ruby

begin
  # Update existing link type.
  data, status_code, headers = api_instance.update_link_type_with_http_info(id, link_type)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <LinkTypeSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->update_link_type_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the link type. |  |
| **link_type** | [**LinkType**](LinkType.md) | JSON array or formdata with updated link type information. See the model for the exact specifications. |  |

### Return type

[**LinkTypeSingle**](LinkTypeSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_transaction_link

> <TransactionLinkSingle> update_transaction_link(id, transaction_link)

Update an existing link between transactions.

Used to update a single existing link. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::LinksApi.new
id = 1 # Integer | The ID of the transaction link.
transaction_link = FireflyIIIClient::TransactionLink.new({ link_type_id: 5, inward_id: 131, outward_id: 131 }) # TransactionLink | JSON array or formdata with updated link type information. See the model for the exact specifications.

begin
  # Update an existing link between transactions.
  result = api_instance.update_transaction_link(id, transaction_link)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->update_transaction_link: #{e}"
end
```

#### Using the update_transaction_link_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionLinkSingle>, Integer, Hash)> update_transaction_link_with_http_info(id, transaction_link)

```ruby

begin
  # Update an existing link between transactions.
  data, status_code, headers = api_instance.update_transaction_link_with_http_info(id, transaction_link)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionLinkSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling LinksApi->update_transaction_link_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the transaction link. |  |
| **transaction_link** | [**TransactionLink**](TransactionLink.md) | JSON array or formdata with updated link type information. See the model for the exact specifications. |  |

### Return type

[**TransactionLinkSingle**](TransactionLinkSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

