# FireflyIIIClient::PreferencesApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**get_preference**](PreferencesApi.md#get_preference) | **GET** /api/v1/preferences/{name} | Return a single preference. |
| [**list_preference**](PreferencesApi.md#list_preference) | **GET** /api/v1/preferences | List all users preferences. |
| [**update_preference**](PreferencesApi.md#update_preference) | **PUT** /api/v1/preferences/{name} | Update preference |


## get_preference

> <PreferenceSingle> get_preference(name)

Return a single preference.

Return a single preference.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::PreferencesApi.new
name = 'currencyPreference' # String | The name of the preference.

begin
  # Return a single preference.
  result = api_instance.get_preference(name)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling PreferencesApi->get_preference: #{e}"
end
```

#### Using the get_preference_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<PreferenceSingle>, Integer, Hash)> get_preference_with_http_info(name)

```ruby

begin
  # Return a single preference.
  data, status_code, headers = api_instance.get_preference_with_http_info(name)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <PreferenceSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling PreferencesApi->get_preference_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **name** | **String** | The name of the preference. |  |

### Return type

[**PreferenceSingle**](PreferenceSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_preference

> <PreferenceArray> list_preference(opts)

List all users preferences.

List all preferences of the user.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::PreferencesApi.new
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # List all users preferences.
  result = api_instance.list_preference(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling PreferencesApi->list_preference: #{e}"
end
```

#### Using the list_preference_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<PreferenceArray>, Integer, Hash)> list_preference_with_http_info(opts)

```ruby

begin
  # List all users preferences.
  data, status_code, headers = api_instance.list_preference_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <PreferenceArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling PreferencesApi->list_preference_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**PreferenceArray**](PreferenceArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_preference

> <PreferenceSingle> update_preference(name, preference)

Update preference

Update a user's preference.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::PreferencesApi.new
name = 'currencyPreference' # String | The name of the preference. Will always overwrite. Will be created if it does not exist.
preference = FireflyIIIClient::Preference.new({ data: 'EUR' }) # Preference | JSON array or key=value pairs with the necessary preference information. See the model for the exact specifications.

begin
  # Update preference
  result = api_instance.update_preference(name, preference)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling PreferencesApi->update_preference: #{e}"
end
```

#### Using the update_preference_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<PreferenceSingle>, Integer, Hash)> update_preference_with_http_info(name, preference)

```ruby

begin
  # Update preference
  data, status_code, headers = api_instance.update_preference_with_http_info(name, preference)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <PreferenceSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling PreferencesApi->update_preference_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **name** | **String** | The name of the preference. Will always overwrite. Will be created if it does not exist. |  |
| **preference** | [**Preference**](Preference.md) | JSON array or key&#x3D;value pairs with the necessary preference information. See the model for the exact specifications. |  |

### Return type

[**PreferenceSingle**](PreferenceSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

