# FireflyIIIClient::RecurrencesApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_recurrence**](RecurrencesApi.md#delete_recurrence) | **DELETE** /api/v1/recurrences/{id} | Delete a recurring transaction. |
| [**get_recurrence**](RecurrencesApi.md#get_recurrence) | **GET** /api/v1/recurrences/{id} | Get a single recurring transaction. |
| [**list_recurrence**](RecurrencesApi.md#list_recurrence) | **GET** /api/v1/recurrences | List all recurring transactions. |
| [**list_transaction_by_recurrence**](RecurrencesApi.md#list_transaction_by_recurrence) | **GET** /api/v1/recurrences/{id}/transactions | List all transactions created by a recurring transaction. |
| [**store_recurrence**](RecurrencesApi.md#store_recurrence) | **POST** /api/v1/recurrences | Store a new recurring transaction |
| [**trigger_recurrence**](RecurrencesApi.md#trigger_recurrence) | **POST** /api/v1/recurrences/trigger | Trigger the creation of recurring transactions (like a cron job). |
| [**update_recurrence**](RecurrencesApi.md#update_recurrence) | **PUT** /api/v1/recurrences/{id} | Update existing recurring transaction. |


## delete_recurrence

> delete_recurrence(id)

Delete a recurring transaction.

Delete a recurring transaction. Transactions created will not be deleted.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RecurrencesApi.new
id = 1 # Integer | The ID of the recurring transaction.

begin
  # Delete a recurring transaction.
  api_instance.delete_recurrence(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->delete_recurrence: #{e}"
end
```

#### Using the delete_recurrence_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_recurrence_with_http_info(id)

```ruby

begin
  # Delete a recurring transaction.
  data, status_code, headers = api_instance.delete_recurrence_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->delete_recurrence_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the recurring transaction. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_recurrence

> <RecurrenceSingle> get_recurrence(id)

Get a single recurring transaction.

Get a single recurring transaction.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RecurrencesApi.new
id = 1 # Integer | The ID of the recurring transaction.

begin
  # Get a single recurring transaction.
  result = api_instance.get_recurrence(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->get_recurrence: #{e}"
end
```

#### Using the get_recurrence_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RecurrenceSingle>, Integer, Hash)> get_recurrence_with_http_info(id)

```ruby

begin
  # Get a single recurring transaction.
  data, status_code, headers = api_instance.get_recurrence_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RecurrenceSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->get_recurrence_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the recurring transaction. |  |

### Return type

[**RecurrenceSingle**](RecurrenceSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_recurrence

> <RecurrenceArray> list_recurrence(opts)

List all recurring transactions.

List all recurring transactions.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RecurrencesApi.new
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # List all recurring transactions.
  result = api_instance.list_recurrence(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->list_recurrence: #{e}"
end
```

#### Using the list_recurrence_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RecurrenceArray>, Integer, Hash)> list_recurrence_with_http_info(opts)

```ruby

begin
  # List all recurring transactions.
  data, status_code, headers = api_instance.list_recurrence_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RecurrenceArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->list_recurrence_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**RecurrenceArray**](RecurrenceArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction_by_recurrence

> <TransactionArray> list_transaction_by_recurrence(id, opts)

List all transactions created by a recurring transaction.

List all transactions created by a recurring transaction, optionally limited to the date ranges specified.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RecurrencesApi.new
id = 1 # Integer | The ID of the recurring transaction.
opts = {
  page: 1, # Integer | Page number. The default pagination is 50.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. Both the start and end date must be present. 
  _end: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. Both the start and end date must be present. 
  type: FireflyIIIClient::TransactionTypeFilter::ALL # TransactionTypeFilter | Optional filter on the transaction type(s) returned
}

begin
  # List all transactions created by a recurring transaction.
  result = api_instance.list_transaction_by_recurrence(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->list_transaction_by_recurrence: #{e}"
end
```

#### Using the list_transaction_by_recurrence_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> list_transaction_by_recurrence_with_http_info(id, opts)

```ruby

begin
  # List all transactions created by a recurring transaction.
  data, status_code, headers = api_instance.list_transaction_by_recurrence_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->list_transaction_by_recurrence_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the recurring transaction. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD. Both the start and end date must be present.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD. Both the start and end date must be present.  | [optional] |
| **type** | [**TransactionTypeFilter**](.md) | Optional filter on the transaction type(s) returned | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_recurrence

> <RecurrenceSingle> store_recurrence(recurrence)

Store a new recurring transaction

Creates a new recurring transaction. The data required can be submitted as a JSON body or as a list of parameters.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RecurrencesApi.new
recurrence = FireflyIIIClient::Recurrence.new({ type: 'withdrawal', title: 'Rent', first_date: Date.parse('Sun Sep 17 00:00:00 GMT 2017') }) # Recurrence | JSON array or key=value pairs with the necessary recurring transaction information. See the model for the exact specifications.

begin
  # Store a new recurring transaction
  result = api_instance.store_recurrence(recurrence)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->store_recurrence: #{e}"
end
```

#### Using the store_recurrence_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RecurrenceSingle>, Integer, Hash)> store_recurrence_with_http_info(recurrence)

```ruby

begin
  # Store a new recurring transaction
  data, status_code, headers = api_instance.store_recurrence_with_http_info(recurrence)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RecurrenceSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->store_recurrence_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **recurrence** | [**Recurrence**](Recurrence.md) | JSON array or key&#x3D;value pairs with the necessary recurring transaction information. See the model for the exact specifications. |  |

### Return type

[**RecurrenceSingle**](RecurrenceSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## trigger_recurrence

> trigger_recurrence

Trigger the creation of recurring transactions (like a cron job).

Triggers the recurring transactions, like a cron job would. If the schedule does not call for a new transaction to be created, nothing will happen. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RecurrencesApi.new

begin
  # Trigger the creation of recurring transactions (like a cron job).
  api_instance.trigger_recurrence
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->trigger_recurrence: #{e}"
end
```

#### Using the trigger_recurrence_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> trigger_recurrence_with_http_info

```ruby

begin
  # Trigger the creation of recurring transactions (like a cron job).
  data, status_code, headers = api_instance.trigger_recurrence_with_http_info
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->trigger_recurrence_with_http_info: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## update_recurrence

> <RecurrenceSingle> update_recurrence(id, recurrence)

Update existing recurring transaction.

Update existing recurring transaction.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RecurrencesApi.new
id = 1 # Integer | The ID of the recurring transaction.
recurrence = FireflyIIIClient::Recurrence.new({ type: 'withdrawal', title: 'Rent', first_date: Date.parse('Sun Sep 17 00:00:00 GMT 2017') }) # Recurrence | JSON array with updated recurring transaction information. See the model for the exact specifications.

begin
  # Update existing recurring transaction.
  result = api_instance.update_recurrence(id, recurrence)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->update_recurrence: #{e}"
end
```

#### Using the update_recurrence_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RecurrenceSingle>, Integer, Hash)> update_recurrence_with_http_info(id, recurrence)

```ruby

begin
  # Update existing recurring transaction.
  data, status_code, headers = api_instance.update_recurrence_with_http_info(id, recurrence)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RecurrenceSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RecurrencesApi->update_recurrence_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the recurring transaction. |  |
| **recurrence** | [**Recurrence**](Recurrence.md) | JSON array with updated recurring transaction information. See the model for the exact specifications. |  |

### Return type

[**RecurrenceSingle**](RecurrenceSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

