# FireflyIIIClient::RuleGroupsApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_rule_group**](RuleGroupsApi.md#delete_rule_group) | **DELETE** /api/v1/rule_groups/{id} | Delete a rule group. |
| [**fire_rule_group**](RuleGroupsApi.md#fire_rule_group) | **POST** /api/v1/rule_groups/{id}/trigger | Fire the rule group on your transactions. |
| [**get_rule_group**](RuleGroupsApi.md#get_rule_group) | **GET** /api/v1/rule_groups/{id} | Get a single rule group. |
| [**list_rule_by_group**](RuleGroupsApi.md#list_rule_by_group) | **GET** /api/v1/rule_groups/{id}/rules | List rules in this rule group. |
| [**list_rule_group**](RuleGroupsApi.md#list_rule_group) | **GET** /api/v1/rule_groups | List all rule groups. |
| [**store_rule_group**](RuleGroupsApi.md#store_rule_group) | **POST** /api/v1/rule_groups | Store a new rule group. |
| [**test_rule_group**](RuleGroupsApi.md#test_rule_group) | **GET** /api/v1/rule_groups/{id}/test | Test which transactions would be hit by the rule group. No changes will be made. |
| [**update_rule_group**](RuleGroupsApi.md#update_rule_group) | **PUT** /api/v1/rule_groups/{id} | Update existing rule group. |


## delete_rule_group

> delete_rule_group(id)

Delete a rule group.

Delete a rule group.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RuleGroupsApi.new
id = 1 # Integer | The ID of the rule group.

begin
  # Delete a rule group.
  api_instance.delete_rule_group(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->delete_rule_group: #{e}"
end
```

#### Using the delete_rule_group_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_rule_group_with_http_info(id)

```ruby

begin
  # Delete a rule group.
  data, status_code, headers = api_instance.delete_rule_group_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->delete_rule_group_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the rule group. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## fire_rule_group

> fire_rule_group(id, opts)

Fire the rule group on your transactions.

Fire the rule group on your transactions. Changes will be made by the rules in the rule group! Limit the result if you want to.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RuleGroupsApi.new
id = 1 # Integer | The ID of the rule group.
opts = {
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the transactions the actions will be applied to. Both the start date and the end date must be present. 
  _end: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the transactions the actions will be applied to. Both the start date and the end date must be present. 
  accounts: '1,2,3' # String | Limit the testing of the rule group to these asset accounts. Only asset accounts will be accepted. Other types will be silently dropped. 
}

begin
  # Fire the rule group on your transactions.
  api_instance.fire_rule_group(id, opts)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->fire_rule_group: #{e}"
end
```

#### Using the fire_rule_group_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> fire_rule_group_with_http_info(id, opts)

```ruby

begin
  # Fire the rule group on your transactions.
  data, status_code, headers = api_instance.fire_rule_group_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->fire_rule_group_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the rule group. |  |
| **start** | **Date** | A date formatted YYYY-MM-DD, to limit the transactions the actions will be applied to. Both the start date and the end date must be present.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD, to limit the transactions the actions will be applied to. Both the start date and the end date must be present.  | [optional] |
| **accounts** | **String** | Limit the testing of the rule group to these asset accounts. Only asset accounts will be accepted. Other types will be silently dropped.  | [optional] |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_rule_group

> <RuleGroupSingle> get_rule_group(id)

Get a single rule group.

Get a single rule group. This does not include the rules. For that, see below.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RuleGroupsApi.new
id = 1 # Integer | The ID of the rule group.

begin
  # Get a single rule group.
  result = api_instance.get_rule_group(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->get_rule_group: #{e}"
end
```

#### Using the get_rule_group_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RuleGroupSingle>, Integer, Hash)> get_rule_group_with_http_info(id)

```ruby

begin
  # Get a single rule group.
  data, status_code, headers = api_instance.get_rule_group_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RuleGroupSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->get_rule_group_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the rule group. |  |

### Return type

[**RuleGroupSingle**](RuleGroupSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_rule_by_group

> <RuleArray> list_rule_by_group(id, opts)

List rules in this rule group.

List rules in this rule group.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RuleGroupsApi.new
id = 1 # Integer | The ID of the rule group.
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # List rules in this rule group.
  result = api_instance.list_rule_by_group(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->list_rule_by_group: #{e}"
end
```

#### Using the list_rule_by_group_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RuleArray>, Integer, Hash)> list_rule_by_group_with_http_info(id, opts)

```ruby

begin
  # List rules in this rule group.
  data, status_code, headers = api_instance.list_rule_by_group_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RuleArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->list_rule_by_group_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the rule group. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**RuleArray**](RuleArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_rule_group

> <RuleGroupArray> list_rule_group(opts)

List all rule groups.

List all rule groups.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RuleGroupsApi.new
opts = {
  page: 1 # Integer | Page number. The default pagination is 50
}

begin
  # List all rule groups.
  result = api_instance.list_rule_group(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->list_rule_group: #{e}"
end
```

#### Using the list_rule_group_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RuleGroupArray>, Integer, Hash)> list_rule_group_with_http_info(opts)

```ruby

begin
  # List all rule groups.
  data, status_code, headers = api_instance.list_rule_group_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RuleGroupArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->list_rule_group_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50 | [optional] |

### Return type

[**RuleGroupArray**](RuleGroupArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_rule_group

> <RuleGroupSingle> store_rule_group(rule_group)

Store a new rule group.

Creates a new rule group. The data required can be submitted as a JSON body or as a list of parameters.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RuleGroupsApi.new
rule_group = FireflyIIIClient::RuleGroup.new({ title: 'Default rule group' }) # RuleGroup | JSON array or key=value pairs with the necessary rule group information. See the model for the exact specifications.

begin
  # Store a new rule group.
  result = api_instance.store_rule_group(rule_group)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->store_rule_group: #{e}"
end
```

#### Using the store_rule_group_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RuleGroupSingle>, Integer, Hash)> store_rule_group_with_http_info(rule_group)

```ruby

begin
  # Store a new rule group.
  data, status_code, headers = api_instance.store_rule_group_with_http_info(rule_group)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RuleGroupSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->store_rule_group_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **rule_group** | [**RuleGroup**](RuleGroup.md) | JSON array or key&#x3D;value pairs with the necessary rule group information. See the model for the exact specifications. |  |

### Return type

[**RuleGroupSingle**](RuleGroupSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## test_rule_group

> <TransactionArray> test_rule_group(id, opts)

Test which transactions would be hit by the rule group. No changes will be made.

Test which transactions would be hit by the rule group. No changes will be made. Limit the result if you want to.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RuleGroupsApi.new
id = 1 # Integer | The ID of the rule group.
opts = {
  page: 1, # Integer | Page number. The default pagination is 50 items.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the transactions the test will be applied to. Both the start date and the end date must be present. 
  _end: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the transactions the test will be applied to. Both the start date and the end date must be present. 
  search_limit: 56, # Integer | Maximum number of transactions Firefly III will try. Don't set this too high, or it will take Firefly III very long to run the test. I suggest a max of 200. 
  triggered_limit: 56, # Integer | Maximum number of transactions the rule group can actually trigger on, before Firefly III stops. I would suggest setting this to 10 or 15. Don't go above the user's page size, because browsing to page 2 or 3 of a test result would fire the test again, making any navigation efforts very slow. 
  accounts: '1,2,3' # String | Limit the testing of the rule group to these asset accounts. Only asset accounts will be accepted. Other types will be silently dropped. 
}

begin
  # Test which transactions would be hit by the rule group. No changes will be made.
  result = api_instance.test_rule_group(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->test_rule_group: #{e}"
end
```

#### Using the test_rule_group_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> test_rule_group_with_http_info(id, opts)

```ruby

begin
  # Test which transactions would be hit by the rule group. No changes will be made.
  data, status_code, headers = api_instance.test_rule_group_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->test_rule_group_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the rule group. |  |
| **page** | **Integer** | Page number. The default pagination is 50 items. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD, to limit the transactions the test will be applied to. Both the start date and the end date must be present.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD, to limit the transactions the test will be applied to. Both the start date and the end date must be present.  | [optional] |
| **search_limit** | **Integer** | Maximum number of transactions Firefly III will try. Don&#39;t set this too high, or it will take Firefly III very long to run the test. I suggest a max of 200.  | [optional] |
| **triggered_limit** | **Integer** | Maximum number of transactions the rule group can actually trigger on, before Firefly III stops. I would suggest setting this to 10 or 15. Don&#39;t go above the user&#39;s page size, because browsing to page 2 or 3 of a test result would fire the test again, making any navigation efforts very slow.  | [optional] |
| **accounts** | **String** | Limit the testing of the rule group to these asset accounts. Only asset accounts will be accepted. Other types will be silently dropped.  | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_rule_group

> <RuleGroupSingle> update_rule_group(id, rule_group)

Update existing rule group.

Update existing rule group.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RuleGroupsApi.new
id = 1 # Integer | The ID of the rule group.
rule_group = FireflyIIIClient::RuleGroup.new({ title: 'Default rule group' }) # RuleGroup | JSON array with updated rule group information. See the model for the exact specifications.

begin
  # Update existing rule group.
  result = api_instance.update_rule_group(id, rule_group)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->update_rule_group: #{e}"
end
```

#### Using the update_rule_group_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RuleGroupSingle>, Integer, Hash)> update_rule_group_with_http_info(id, rule_group)

```ruby

begin
  # Update existing rule group.
  data, status_code, headers = api_instance.update_rule_group_with_http_info(id, rule_group)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RuleGroupSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RuleGroupsApi->update_rule_group_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the rule group. |  |
| **rule_group** | [**RuleGroup**](RuleGroup.md) | JSON array with updated rule group information. See the model for the exact specifications. |  |

### Return type

[**RuleGroupSingle**](RuleGroupSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

