# FireflyIIIClient::RulesApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_rule**](RulesApi.md#delete_rule) | **DELETE** /api/v1/rules/{id} | Delete an rule. |
| [**fire_rule**](RulesApi.md#fire_rule) | **POST** /api/v1/rules/{id}/trigger | Fire the rule on your transactions. |
| [**get_rule**](RulesApi.md#get_rule) | **GET** /api/v1/rules/{id} | Get a single rule. |
| [**list_rule**](RulesApi.md#list_rule) | **GET** /api/v1/rules | List all rules. |
| [**store_rule**](RulesApi.md#store_rule) | **POST** /api/v1/rules | Store a new rule |
| [**test_rule**](RulesApi.md#test_rule) | **GET** /api/v1/rules/{id}/test | Test which transactions would be hit by the rule. No changes will be made. |
| [**update_rule**](RulesApi.md#update_rule) | **PUT** /api/v1/rules/{id} | Update existing rule. |


## delete_rule

> delete_rule(id)

Delete an rule.

Delete an rule.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RulesApi.new
id = 1 # Integer | The ID of the rule.

begin
  # Delete an rule.
  api_instance.delete_rule(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->delete_rule: #{e}"
end
```

#### Using the delete_rule_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_rule_with_http_info(id)

```ruby

begin
  # Delete an rule.
  data, status_code, headers = api_instance.delete_rule_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->delete_rule_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the rule. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## fire_rule

> fire_rule(id, opts)

Fire the rule on your transactions.

Fire the rule group on your transactions. Changes will be made by the rules in the group! Limit the result if you want to.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RulesApi.new
id = 1 # Integer | The ID of the rule.
opts = {
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the transactions the actions will be applied to. Both the start date and the end date must be present. 
  _end: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the transactions the actions will be applied to. Both the start date and the end date must be present. 
  accounts: '1,2,3' # String | Limit the testing of the rule to these asset accounts. Only asset accounts will be accepted. Other types will be silently dropped. 
}

begin
  # Fire the rule on your transactions.
  api_instance.fire_rule(id, opts)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->fire_rule: #{e}"
end
```

#### Using the fire_rule_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> fire_rule_with_http_info(id, opts)

```ruby

begin
  # Fire the rule on your transactions.
  data, status_code, headers = api_instance.fire_rule_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->fire_rule_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the rule. |  |
| **start** | **Date** | A date formatted YYYY-MM-DD, to limit the transactions the actions will be applied to. Both the start date and the end date must be present.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD, to limit the transactions the actions will be applied to. Both the start date and the end date must be present.  | [optional] |
| **accounts** | **String** | Limit the testing of the rule to these asset accounts. Only asset accounts will be accepted. Other types will be silently dropped.  | [optional] |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_rule

> <RuleSingle> get_rule(id)

Get a single rule.

Get a single rule.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RulesApi.new
id = 1 # Integer | The ID of the object.X

begin
  # Get a single rule.
  result = api_instance.get_rule(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->get_rule: #{e}"
end
```

#### Using the get_rule_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RuleSingle>, Integer, Hash)> get_rule_with_http_info(id)

```ruby

begin
  # Get a single rule.
  data, status_code, headers = api_instance.get_rule_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RuleSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->get_rule_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the object.X |  |

### Return type

[**RuleSingle**](RuleSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_rule

> <RuleArray> list_rule(opts)

List all rules.

List all rules.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RulesApi.new
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # List all rules.
  result = api_instance.list_rule(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->list_rule: #{e}"
end
```

#### Using the list_rule_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RuleArray>, Integer, Hash)> list_rule_with_http_info(opts)

```ruby

begin
  # List all rules.
  data, status_code, headers = api_instance.list_rule_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RuleArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->list_rule_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**RuleArray**](RuleArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_rule

> <RuleSingle> store_rule(rule)

Store a new rule

Creates a new rule. The data required can be submitted as a JSON body or as a list of parameters.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RulesApi.new
rule = FireflyIIIClient::Rule.new({ title: 'First rule title.', rule_group_id: 81, trigger: 'store-journal', triggers: [FireflyIIIClient::RuleTrigger.new({ type: 'from_account_starts', value: 'tag1' })], actions: [FireflyIIIClient::RuleAction.new({ type: 'user_action', value: 'Daily groceries' })] }) # Rule | JSON array or key=value pairs with the necessary rule information. See the model for the exact specifications.

begin
  # Store a new rule
  result = api_instance.store_rule(rule)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->store_rule: #{e}"
end
```

#### Using the store_rule_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RuleSingle>, Integer, Hash)> store_rule_with_http_info(rule)

```ruby

begin
  # Store a new rule
  data, status_code, headers = api_instance.store_rule_with_http_info(rule)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RuleSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->store_rule_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **rule** | [**Rule**](Rule.md) | JSON array or key&#x3D;value pairs with the necessary rule information. See the model for the exact specifications. |  |

### Return type

[**RuleSingle**](RuleSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## test_rule

> <TransactionArray> test_rule(id, opts)

Test which transactions would be hit by the rule. No changes will be made.

Test which transactions would be hit by the rule. No changes will be made. Limit the result if you want to.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RulesApi.new
id = 1 # Integer | The ID of the rule.
opts = {
  page: 1, # Integer | Page number. The default pagination is 50 items.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the transactions the test will be applied to. Both the start date and the end date must be present. 
  _end: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD, to limit the transactions the test will be applied to. Both the start date and the end date must be present. 
  search_limit: 56, # Integer | Maximum number of transactions Firefly III will try. Don't set this too high, or it will take Firefly III very long to run the test. I suggest a max of 200. 
  triggered_limit: 56, # Integer | Maximum number of transactions the rule can actually trigger on, before Firefly III stops. I would suggest setting this to 10 or 15. Don't go above the user's page size, because browsing to page 2 or 3 of a test result would fire the test again, making any navigation efforts very slow. 
  accounts: '1,2,3' # String | Limit the testing of the rule to these asset accounts. Only asset accounts will be accepted. Other types will be silently dropped. 
}

begin
  # Test which transactions would be hit by the rule. No changes will be made.
  result = api_instance.test_rule(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->test_rule: #{e}"
end
```

#### Using the test_rule_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> test_rule_with_http_info(id, opts)

```ruby

begin
  # Test which transactions would be hit by the rule. No changes will be made.
  data, status_code, headers = api_instance.test_rule_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->test_rule_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the rule. |  |
| **page** | **Integer** | Page number. The default pagination is 50 items. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD, to limit the transactions the test will be applied to. Both the start date and the end date must be present.  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD, to limit the transactions the test will be applied to. Both the start date and the end date must be present.  | [optional] |
| **search_limit** | **Integer** | Maximum number of transactions Firefly III will try. Don&#39;t set this too high, or it will take Firefly III very long to run the test. I suggest a max of 200.  | [optional] |
| **triggered_limit** | **Integer** | Maximum number of transactions the rule can actually trigger on, before Firefly III stops. I would suggest setting this to 10 or 15. Don&#39;t go above the user&#39;s page size, because browsing to page 2 or 3 of a test result would fire the test again, making any navigation efforts very slow.  | [optional] |
| **accounts** | **String** | Limit the testing of the rule to these asset accounts. Only asset accounts will be accepted. Other types will be silently dropped.  | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_rule

> <RuleSingle> update_rule(id, rule)

Update existing rule.

Update existing rule.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::RulesApi.new
id = 1 # Integer | The ID of the object.X
rule = FireflyIIIClient::Rule.new({ title: 'First rule title.', rule_group_id: 81, trigger: 'store-journal', triggers: [FireflyIIIClient::RuleTrigger.new({ type: 'from_account_starts', value: 'tag1' })], actions: [FireflyIIIClient::RuleAction.new({ type: 'user_action', value: 'Daily groceries' })] }) # Rule | JSON array with updated rule information. See the model for the exact specifications.

begin
  # Update existing rule.
  result = api_instance.update_rule(id, rule)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->update_rule: #{e}"
end
```

#### Using the update_rule_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<RuleSingle>, Integer, Hash)> update_rule_with_http_info(id, rule)

```ruby

begin
  # Update existing rule.
  data, status_code, headers = api_instance.update_rule_with_http_info(id, rule)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <RuleSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling RulesApi->update_rule_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the object.X |  |
| **rule** | [**Rule**](Rule.md) | JSON array with updated rule information. See the model for the exact specifications. |  |

### Return type

[**RuleSingle**](RuleSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

