# FireflyIIIClient::TagsApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_tag**](TagsApi.md#delete_tag) | **DELETE** /api/v1/tags/{tag} | Delete an tag. |
| [**get_tag**](TagsApi.md#get_tag) | **GET** /api/v1/tags/{tag} | Get a single tag. |
| [**get_tag_cloud**](TagsApi.md#get_tag_cloud) | **GET** /api/v1/tag-cloud | Returns a basic tag cloud. |
| [**list_tag**](TagsApi.md#list_tag) | **GET** /api/v1/tags | List all tags. |
| [**list_transaction_by_tag**](TagsApi.md#list_transaction_by_tag) | **GET** /api/v1/tags/{tag}/transactions | List all transactions with this tag. |
| [**store_tag**](TagsApi.md#store_tag) | **POST** /api/v1/tags | Store a new tag |
| [**update_tag**](TagsApi.md#update_tag) | **PUT** /api/v1/tags/{tag} | Update existing tag. |


## delete_tag

> delete_tag(tag)

Delete an tag.

Delete an tag.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TagsApi.new
tag = 'groceries' # String | Either the tag itself or the tag ID.

begin
  # Delete an tag.
  api_instance.delete_tag(tag)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->delete_tag: #{e}"
end
```

#### Using the delete_tag_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_tag_with_http_info(tag)

```ruby

begin
  # Delete an tag.
  data, status_code, headers = api_instance.delete_tag_with_http_info(tag)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->delete_tag_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **tag** | **String** | Either the tag itself or the tag ID. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_tag

> <TagSingle> get_tag(tag, opts)

Get a single tag.

Get a single tag.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TagsApi.new
tag = 'groceries' # String | Either the tag itself or the tag ID.
opts = {
  page: 56 # Integer | Page number
}

begin
  # Get a single tag.
  result = api_instance.get_tag(tag, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->get_tag: #{e}"
end
```

#### Using the get_tag_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TagSingle>, Integer, Hash)> get_tag_with_http_info(tag, opts)

```ruby

begin
  # Get a single tag.
  data, status_code, headers = api_instance.get_tag_with_http_info(tag, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TagSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->get_tag_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **tag** | **String** | Either the tag itself or the tag ID. |  |
| **page** | **Integer** | Page number | [optional] |

### Return type

[**TagSingle**](TagSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_tag_cloud

> <TagCloud> get_tag_cloud(start, _end)

Returns a basic tag cloud.

Returns a list of tags, which can be used to draw a basic tag cloud.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TagsApi.new
start = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 
_end = Date.parse('2013-10-20') # Date | A date formatted YYYY-MM-DD. 

begin
  # Returns a basic tag cloud.
  result = api_instance.get_tag_cloud(start, _end)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->get_tag_cloud: #{e}"
end
```

#### Using the get_tag_cloud_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TagCloud>, Integer, Hash)> get_tag_cloud_with_http_info(start, _end)

```ruby

begin
  # Returns a basic tag cloud.
  data, status_code, headers = api_instance.get_tag_cloud_with_http_info(start, _end)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TagCloud>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->get_tag_cloud_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **start** | **Date** | A date formatted YYYY-MM-DD.  |  |
| **_end** | **Date** | A date formatted YYYY-MM-DD.  |  |

### Return type

[**TagCloud**](TagCloud.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_tag

> <TagArray> list_tag(opts)

List all tags.

List all of the user's tags.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TagsApi.new
opts = {
  page: 56 # Integer | Page number
}

begin
  # List all tags.
  result = api_instance.list_tag(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->list_tag: #{e}"
end
```

#### Using the list_tag_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TagArray>, Integer, Hash)> list_tag_with_http_info(opts)

```ruby

begin
  # List all tags.
  data, status_code, headers = api_instance.list_tag_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TagArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->list_tag_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number | [optional] |

### Return type

[**TagArray**](TagArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction_by_tag

> <TransactionArray> list_transaction_by_tag(tag, opts)

List all transactions with this tag.

List all transactions with this tag.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TagsApi.new
tag = 'groceries' # String | Either the tag itself or the tag ID.
opts = {
  page: 1, # Integer | Page number. The default pagination is 50.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. This is the start date of the selected range (inclusive). 
  _end: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. This is the end date of the selected range (inclusive). 
  type: FireflyIIIClient::TransactionTypeFilter::ALL # TransactionTypeFilter | Optional filter on the transaction type(s) returned.
}

begin
  # List all transactions with this tag.
  result = api_instance.list_transaction_by_tag(tag, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->list_transaction_by_tag: #{e}"
end
```

#### Using the list_transaction_by_tag_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> list_transaction_by_tag_with_http_info(tag, opts)

```ruby

begin
  # List all transactions with this tag.
  data, status_code, headers = api_instance.list_transaction_by_tag_with_http_info(tag, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->list_transaction_by_tag_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **tag** | **String** | Either the tag itself or the tag ID. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD. This is the start date of the selected range (inclusive).  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD. This is the end date of the selected range (inclusive).  | [optional] |
| **type** | [**TransactionTypeFilter**](.md) | Optional filter on the transaction type(s) returned. | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_tag

> <TagSingle> store_tag(tag_model)

Store a new tag

Creates a new tag. The data required can be submitted as a JSON body or as a list of parameters.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TagsApi.new
tag_model = FireflyIIIClient::TagModel.new({ tag: 'expensive' }) # TagModel | JSON array or key=value pairs with the necessary tag information. See the model for the exact specifications.

begin
  # Store a new tag
  result = api_instance.store_tag(tag_model)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->store_tag: #{e}"
end
```

#### Using the store_tag_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TagSingle>, Integer, Hash)> store_tag_with_http_info(tag_model)

```ruby

begin
  # Store a new tag
  data, status_code, headers = api_instance.store_tag_with_http_info(tag_model)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TagSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->store_tag_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **tag_model** | [**TagModel**](TagModel.md) | JSON array or key&#x3D;value pairs with the necessary tag information. See the model for the exact specifications. |  |

### Return type

[**TagSingle**](TagSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_tag

> <TagSingle> update_tag(tag, tag_model)

Update existing tag.

Update existing tag.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TagsApi.new
tag = 'groceries' # String | Either the tag itself or the tag ID.
tag_model = FireflyIIIClient::TagModel.new({ tag: 'expensive' }) # TagModel | JSON array with updated tag information. See the model for the exact specifications.

begin
  # Update existing tag.
  result = api_instance.update_tag(tag, tag_model)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->update_tag: #{e}"
end
```

#### Using the update_tag_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TagSingle>, Integer, Hash)> update_tag_with_http_info(tag, tag_model)

```ruby

begin
  # Update existing tag.
  data, status_code, headers = api_instance.update_tag_with_http_info(tag, tag_model)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TagSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TagsApi->update_tag_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **tag** | **String** | Either the tag itself or the tag ID. |  |
| **tag_model** | [**TagModel**](TagModel.md) | JSON array with updated tag information. See the model for the exact specifications. |  |

### Return type

[**TagSingle**](TagSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

