# FireflyIIIClient::TransactionSplit

## Properties

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **user** | **Integer** | User ID | [optional][readonly] |
| **transaction_journal_id** | **Integer** | ID of the underlying transaction journal. Each transaction consists of a transaction group (see the top ID) and one or more journals making up the splits of the transaction.  | [optional][readonly] |
| **type** | **String** | Type of transaction. expense cannot be written. | [optional] |
| **date** | **Date** | Date of the transaction |  |
| **amount** | **Float** | Amount of the transaction. |  |
| **description** | **String** | Description of the transaction. Will only be used if more than one split is submitted. |  |
| **order** | **Integer** | Order of this entry in the list of transactions. | [optional] |
| **currency_id** | **Integer** | Currency ID. Default is the source account&#39;s currency, or the user&#39;s default currency. Can be used instead of currency_code. | [optional] |
| **currency_code** | **String** | Currency code. Default is the source account&#39;s currency, or the user&#39;s default currency. Can be used instead of currency_id. | [optional] |
| **currency_symbol** | **String** |  | [optional][readonly] |
| **currency_name** | **String** |  | [optional][readonly] |
| **currency_decimal_places** | **Integer** | Number of decimals used in this currency. | [optional][readonly] |
| **foreign_amount** | **Float** | The amount in a foreign currency. | [optional] |
| **foreign_currency_id** | **Integer** | Currency ID. Default is null. Is required when you submit a foreign amount. | [optional] |
| **foreign_currency_code** | **String** | Currency code. Default is NULL. Can be used instead of the foreign_currency_id, but either is required when submitting a foreign amount. | [optional] |
| **foreign_currency_symbol** | **String** |  | [optional][readonly] |
| **foreign_currency_decimal_places** | **Integer** | Number of decimals in the currency | [optional][readonly] |
| **budget_id** | **Integer** | The budget ID for this transaction. | [optional] |
| **budget_name** | **String** | The name of the budget to be used. If the budget name is unknown, the ID will be used or the value will be ignored. | [optional][readonly] |
| **category_id** | **Integer** | The category ID for this transaction. | [optional] |
| **category_name** | **String** | The name of the category to be used. If the category is unknown, it will be created. If the ID and the name point to different categories, the ID overrules the name. | [optional] |
| **source_id** | **Integer** | ID of the source account. For a withdrawal or a transfer, this must always be an asset account. For deposits, this must be a revenue account. | [optional] |
| **source_name** | **String** | Name of the source account. For a withdrawal or a transfer, this must always be an asset account. For deposits, this must be a revenue account. Can be used instead of the source_id. If the transaction is a deposit, the source_name can be filled in freely: the account will be created based on the name. | [optional] |
| **source_iban** | **String** |  | [optional][readonly] |
| **source_type** | [**AccountTypeProperty**](AccountTypeProperty.md) |  | [optional] |
| **destination_id** | **Integer** | ID of the destination account. For a deposit or a transfer, this must always be an asset account. For withdrawals this must be an expense account. | [optional] |
| **destination_name** | **String** | Name of the destination account. You can submit the name instead of the ID. For everything except transfers, the account will be auto-generated if unknown, so submitting a name is enough. | [optional] |
| **destination_iban** | **String** |  | [optional][readonly] |
| **destination_type** | [**AccountTypeProperty**](AccountTypeProperty.md) |  | [optional] |
| **reconciled** | **Boolean** | If the transaction has been reconciled already. When you set this, the amount can no longer be edited by the user. | [optional] |
| **piggy_bank_id** | **Integer** | Optional. Use either this or the piggy_bank_name | [optional] |
| **piggy_bank_name** | **String** | Optional. Use either this or the piggy_bank_id | [optional] |
| **bill_id** | **Integer** | Optional. Use either this or the bill_name | [optional] |
| **bill_name** | **String** | Optional. Use either this or the bill_id | [optional] |
| **tags** | **Array&lt;String&gt;** | Array of tags. | [optional] |
| **notes** | **String** |  | [optional] |
| **internal_reference** | **String** | Reference to internal reference of other systems. | [optional] |
| **external_id** | **String** | Reference to external ID in other systems. | [optional] |
| **original_source** | **String** | System generated identifier for original creator of transaction. | [optional][readonly] |
| **recurrence_id** | **Integer** | Reference to recurrence that made the transaction. | [optional][readonly] |
| **bunq_payment_id** | **String** | Internal ID of bunq transaction. | [optional] |
| **import_hash_v2** | **String** | Hash value of original import transaction (for duplicate detection). | [optional][readonly] |
| **sepa_cc** | **String** | SEPA Clearing Code | [optional] |
| **sepa_ct_op** | **String** | SEPA Opposing Account Identifier | [optional] |
| **sepa_ct_id** | **String** | SEPA end-to-end Identifier | [optional] |
| **sepa_db** | **String** | SEPA mandate identifier | [optional] |
| **sepa_country** | **String** | SEPA Country | [optional] |
| **sepa_ep** | **String** | SEPA External Purpose indicator | [optional] |
| **sepa_ci** | **String** | SEPA Creditor Identifier | [optional] |
| **sepa_batch_id** | **String** | SEPA Batch ID | [optional] |
| **interest_date** | **Date** |  | [optional] |
| **book_date** | **Date** |  | [optional] |
| **process_date** | **Date** |  | [optional] |
| **due_date** | **Date** |  | [optional] |
| **payment_date** | **Date** |  | [optional] |
| **invoice_date** | **Date** |  | [optional] |

## Example

```ruby
require 'firefly_iii_client'

instance = FireflyIIIClient::TransactionSplit.new(
  user: 3,
  transaction_journal_id: 10421,
  type: withdrawal,
  date: Mon Sep 17 00 : 00 : 00 GMT 2018,
                                    amount: 12.95,
                                    description: Vegetables,
                                    order: 0,
                                    currency_id: 12,
                                    currency_code: EUR,
                                    currency_symbol: $,
currency_name : Euro,
    currency_decimal_places : 2,
  foreign_amount : 16.95,
  foreign_currency_id : 17,
  foreign_currency_code : USD,
    foreign_currency_symbol : $,
foreign_currency_decimal_places : 2,
  budget_id : 4,
  budget_name : Groceries,
    category_id : 43,
  category_name : Groceries,
    source_id : 2,
  source_name : Checking account,
                         source_iban: NL02ABNA0123456789,
                         source_type: null,
                         destination_id: 2,
                         destination_name: Buy and Large,
  destination_iban : NL02ABNA0123456789,
    destination_type : null,
    reconciled : false,
    piggy_bank_id : null,
    piggy_bank_name : null,
    bill_id : 111,
  bill_name : Monthly rent,
                      tags: null,
                      notes: Some example notes,
                                          internal_reference: null,
                                          external_id: null,
                                          original_source: null,
                                          recurrence_id: null,
                                          bunq_payment_id: null,
                                          import_hash_v2: null,
                                          sepa_cc: null,
                                          sepa_ct_op: null,
                                          sepa_ct_id: null,
                                          sepa_db: null,
                                          sepa_country: null,
                                          sepa_ep: null,
                                          sepa_ci: null,
                                          sepa_batch_id: null,
                                          interest_date: null,
                                          book_date: null,
                                          process_date: null,
                                          due_date: null,
                                          payment_date: null,
                                          invoice_date: null
)
```

