# FireflyIIIClient::TransactionsApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_transaction**](TransactionsApi.md#delete_transaction) | **DELETE** /api/v1/transactions/{id} | Delete a transaction. |
| [**get_transaction**](TransactionsApi.md#get_transaction) | **GET** /api/v1/transactions/{id} | Get a single transaction. |
| [**get_transaction_by_journal**](TransactionsApi.md#get_transaction_by_journal) | **GET** /api/v1/transaction-journals/{id} | Get a single transaction, based on one of the underlying transaction journals. |
| [**list_attachment_by_transaction**](TransactionsApi.md#list_attachment_by_transaction) | **GET** /api/v1/transactions/{id}/attachments | Lists all attachments. |
| [**list_event_by_transaction**](TransactionsApi.md#list_event_by_transaction) | **GET** /api/v1/transactions/{id}/piggy_bank_events | Lists all piggy bank events. |
| [**list_transaction**](TransactionsApi.md#list_transaction) | **GET** /api/v1/transactions | List all the user&#39;s transactions.  |
| [**store_transaction**](TransactionsApi.md#store_transaction) | **POST** /api/v1/transactions | Store a new transaction |
| [**update_transaction**](TransactionsApi.md#update_transaction) | **PUT** /api/v1/transactions/{id} | Update existing transaction. |


## delete_transaction

> delete_transaction(id)

Delete a transaction.

Delete a transaction.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TransactionsApi.new
id = 1 # Integer | The ID of the transaction.

begin
  # Delete a transaction.
  api_instance.delete_transaction(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->delete_transaction: #{e}"
end
```

#### Using the delete_transaction_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_transaction_with_http_info(id)

```ruby

begin
  # Delete a transaction.
  data, status_code, headers = api_instance.delete_transaction_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->delete_transaction_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the transaction. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_transaction

> <TransactionSingle> get_transaction(id)

Get a single transaction.

Get a single transaction.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TransactionsApi.new
id = 1 # Integer | The ID of the transaction.

begin
  # Get a single transaction.
  result = api_instance.get_transaction(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->get_transaction: #{e}"
end
```

#### Using the get_transaction_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionSingle>, Integer, Hash)> get_transaction_with_http_info(id)

```ruby

begin
  # Get a single transaction.
  data, status_code, headers = api_instance.get_transaction_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->get_transaction_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the transaction. |  |

### Return type

[**TransactionSingle**](TransactionSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_transaction_by_journal

> <TransactionSingle> get_transaction_by_journal(id)

Get a single transaction, based on one of the underlying transaction journals.

Get a single transaction by underlying journal.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TransactionsApi.new
id = 1 # Integer | The ID of the transaction journal.

begin
  # Get a single transaction, based on one of the underlying transaction journals.
  result = api_instance.get_transaction_by_journal(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->get_transaction_by_journal: #{e}"
end
```

#### Using the get_transaction_by_journal_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionSingle>, Integer, Hash)> get_transaction_by_journal_with_http_info(id)

```ruby

begin
  # Get a single transaction, based on one of the underlying transaction journals.
  data, status_code, headers = api_instance.get_transaction_by_journal_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->get_transaction_by_journal_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the transaction journal. |  |

### Return type

[**TransactionSingle**](TransactionSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_attachment_by_transaction

> <AttachmentArray> list_attachment_by_transaction(id, opts)

Lists all attachments.

Lists all attachments.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TransactionsApi.new
id = 1 # Integer | The ID of the transaction.
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # Lists all attachments.
  result = api_instance.list_attachment_by_transaction(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->list_attachment_by_transaction: #{e}"
end
```

#### Using the list_attachment_by_transaction_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AttachmentArray>, Integer, Hash)> list_attachment_by_transaction_with_http_info(id, opts)

```ruby

begin
  # Lists all attachments.
  data, status_code, headers = api_instance.list_attachment_by_transaction_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AttachmentArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->list_attachment_by_transaction_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the transaction. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**AttachmentArray**](AttachmentArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_event_by_transaction

> <PiggyBankEventArray> list_event_by_transaction(id, opts)

Lists all piggy bank events.

Lists all piggy bank events.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TransactionsApi.new
id = 1 # Integer | The ID of the transaction.
opts = {
  page: 1 # Integer | Page number. The default pagination is 50.
}

begin
  # Lists all piggy bank events.
  result = api_instance.list_event_by_transaction(id, opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->list_event_by_transaction: #{e}"
end
```

#### Using the list_event_by_transaction_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<PiggyBankEventArray>, Integer, Hash)> list_event_by_transaction_with_http_info(id, opts)

```ruby

begin
  # Lists all piggy bank events.
  data, status_code, headers = api_instance.list_event_by_transaction_with_http_info(id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <PiggyBankEventArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->list_event_by_transaction_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the transaction. |  |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |

### Return type

[**PiggyBankEventArray**](PiggyBankEventArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_transaction

> <TransactionArray> list_transaction(opts)

List all the user's transactions. 

List all the user's transactions.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TransactionsApi.new
opts = {
  page: 1, # Integer | Page number. The default pagination is 50.
  start: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. This is the start date of the selected range (inclusive). 
  _end: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), # Date | A date formatted YYYY-MM-DD. This is the end date of the selected range (inclusive). 
  type: FireflyIIIClient::TransactionTypeFilter::ALL # TransactionTypeFilter | Optional filter on the transaction type(s) returned.
}

begin
  # List all the user's transactions. 
  result = api_instance.list_transaction(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->list_transaction: #{e}"
end
```

#### Using the list_transaction_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionArray>, Integer, Hash)> list_transaction_with_http_info(opts)

```ruby

begin
  # List all the user's transactions. 
  data, status_code, headers = api_instance.list_transaction_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->list_transaction_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | Page number. The default pagination is 50. | [optional] |
| **start** | **Date** | A date formatted YYYY-MM-DD. This is the start date of the selected range (inclusive).  | [optional] |
| **_end** | **Date** | A date formatted YYYY-MM-DD. This is the end date of the selected range (inclusive).  | [optional] |
| **type** | [**TransactionTypeFilter**](.md) | Optional filter on the transaction type(s) returned. | [optional] |

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_transaction

> <TransactionSingle> store_transaction(transaction)

Store a new transaction

Creates a new transaction. The data required can be submitted as a JSON body or as a list of parameters.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TransactionsApi.new
transaction = FireflyIIIClient::Transaction.new({ transactions: [FireflyIIIClient::TransactionSplit.new({ date: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), amount: 12.95, description: 'Vegetables' })] }) # Transaction | JSON array or key=value pairs with the necessary transaction information. See the model for the exact specifications.

begin
  # Store a new transaction
  result = api_instance.store_transaction(transaction)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->store_transaction: #{e}"
end
```

#### Using the store_transaction_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionSingle>, Integer, Hash)> store_transaction_with_http_info(transaction)

```ruby

begin
  # Store a new transaction
  data, status_code, headers = api_instance.store_transaction_with_http_info(transaction)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->store_transaction_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **transaction** | [**Transaction**](Transaction.md) | JSON array or key&#x3D;value pairs with the necessary transaction information. See the model for the exact specifications. |  |

### Return type

[**TransactionSingle**](TransactionSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_transaction

> <TransactionSingle> update_transaction(id, transaction)

Update existing transaction.

Update an existing transaction.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::TransactionsApi.new
id = 1 # Integer | The ID of the transaction.
transaction = FireflyIIIClient::Transaction.new({ transactions: [FireflyIIIClient::TransactionSplit.new({ date: Date.parse('Mon Sep 17 00:00:00 GMT 2018'), amount: 12.95, description: 'Vegetables' })] }) # Transaction | JSON array with updated transaction information. See the model for the exact specifications.

begin
  # Update existing transaction.
  result = api_instance.update_transaction(id, transaction)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->update_transaction: #{e}"
end
```

#### Using the update_transaction_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionSingle>, Integer, Hash)> update_transaction_with_http_info(id, transaction)

```ruby

begin
  # Update existing transaction.
  data, status_code, headers = api_instance.update_transaction_with_http_info(id, transaction)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling TransactionsApi->update_transaction_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The ID of the transaction. |  |
| **transaction** | [**Transaction**](Transaction.md) | JSON array with updated transaction information. See the model for the exact specifications. |  |

### Return type

[**TransactionSingle**](TransactionSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

