# FireflyIIIClient::UsersApi

All URIs are relative to *https://demo.firefly-iii.org*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**delete_user**](UsersApi.md#delete_user) | **DELETE** /api/v1/users/{id} | Delete a user. |
| [**get_user**](UsersApi.md#get_user) | **GET** /api/v1/users/{id} | Get a single user. |
| [**list_user**](UsersApi.md#list_user) | **GET** /api/v1/users | List all users. |
| [**store_user**](UsersApi.md#store_user) | **POST** /api/v1/users | Store a new user |
| [**update_user**](UsersApi.md#update_user) | **PUT** /api/v1/users/{id} | Update an existing user&#39;s information. |


## delete_user

> delete_user(id)

Delete a user.

Delete a user. You cannot delete the current user.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::UsersApi.new
id = 1 # Integer | The user ID.

begin
  # Delete a user.
  api_instance.delete_user(id)
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling UsersApi->delete_user: #{e}"
end
```

#### Using the delete_user_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_user_with_http_info(id)

```ruby

begin
  # Delete a user.
  data, status_code, headers = api_instance.delete_user_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling UsersApi->delete_user_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The user ID. |  |

### Return type

nil (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_user

> <UserSingle> get_user(id)

Get a single user.

Gets all info of a single user.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::UsersApi.new
id = 1 # Integer | The user ID.

begin
  # Get a single user.
  result = api_instance.get_user(id)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling UsersApi->get_user: #{e}"
end
```

#### Using the get_user_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<UserSingle>, Integer, Hash)> get_user_with_http_info(id)

```ruby

begin
  # Get a single user.
  data, status_code, headers = api_instance.get_user_with_http_info(id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <UserSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling UsersApi->get_user_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The user ID. |  |

### Return type

[**UserSingle**](UserSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_user

> <UserArray> list_user(opts)

List all users.

List all the users in this instance of Firefly III.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::UsersApi.new
opts = {
  page: 1 # Integer | The page number, if necessary. The default pagination is 50, so 50 users per page.
}

begin
  # List all users.
  result = api_instance.list_user(opts)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling UsersApi->list_user: #{e}"
end
```

#### Using the list_user_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<UserArray>, Integer, Hash)> list_user_with_http_info(opts)

```ruby

begin
  # List all users.
  data, status_code, headers = api_instance.list_user_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <UserArray>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling UsersApi->list_user_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **page** | **Integer** | The page number, if necessary. The default pagination is 50, so 50 users per page. | [optional] |

### Return type

[**UserArray**](UserArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## store_user

> <UserSingle> store_user(user)

Store a new user

Creates a new user. The data required can be submitted as a JSON body or as a list of parameters. The user will be given a random password, which they can reset using the \"forgot password\" function. 

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::UsersApi.new
user = FireflyIIIClient::User.new({ email: 'thegrumpydictator@gmail.com' }) # User | JSON array or key=value pairs with the necessary user information. See the model for the exact specifications.

begin
  # Store a new user
  result = api_instance.store_user(user)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling UsersApi->store_user: #{e}"
end
```

#### Using the store_user_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<UserSingle>, Integer, Hash)> store_user_with_http_info(user)

```ruby

begin
  # Store a new user
  data, status_code, headers = api_instance.store_user_with_http_info(user)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <UserSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling UsersApi->store_user_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **user** | [**User**](User.md) | JSON array or key&#x3D;value pairs with the necessary user information. See the model for the exact specifications. |  |

### Return type

[**UserSingle**](UserSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json


## update_user

> <UserSingle> update_user(id, user)

Update an existing user's information.

Update existing user.

### Examples

```ruby
require 'time'
require 'firefly_iii_client'
# setup authorization
FireflyIIIClient.configure do |config|
  # Configure OAuth2 access token for authorization: firefly_iii_auth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = FireflyIIIClient::UsersApi.new
id = 1 # Integer | The user ID.
user = FireflyIIIClient::User.new({ email: 'thegrumpydictator@gmail.com' }) # User | JSON array with updated user information. See the model for the exact specifications.

begin
  # Update an existing user's information.
  result = api_instance.update_user(id, user)
  p result
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling UsersApi->update_user: #{e}"
end
```

#### Using the update_user_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<UserSingle>, Integer, Hash)> update_user_with_http_info(id, user)

```ruby

begin
  # Update an existing user's information.
  data, status_code, headers = api_instance.update_user_with_http_info(id, user)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <UserSingle>
rescue FireflyIIIClient::ApiError => e
  puts "Error when calling UsersApi->update_user_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **id** | **Integer** | The user ID. |  |
| **user** | [**User**](User.md) | JSON array with updated user information. See the model for the exact specifications. |  |

### Return type

[**UserSingle**](UserSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded
- **Accept**: application/json

